/****************************************************************************
** Meta object code from reading C++ file 'declarativeareaseries_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/chartsqml2/declarativeareaseries_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativeareaseries_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__DeclarativeAreaSeries_t {
    QByteArrayData data[28];
    char stringdata0[397];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__DeclarativeAreaSeries_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__DeclarativeAreaSeries_t qt_meta_stringdata_QtCharts__DeclarativeAreaSeries = {
    {
QT_MOC_LITERAL(0, 0, 31), // "QtCharts::DeclarativeAreaSeries"
QT_MOC_LITERAL(1, 32, 12), // "axisXChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 14), // "QAbstractAxis*"
QT_MOC_LITERAL(4, 61, 4), // "axis"
QT_MOC_LITERAL(5, 66, 12), // "axisYChanged"
QT_MOC_LITERAL(6, 79, 18), // "borderWidthChanged"
QT_MOC_LITERAL(7, 98, 5), // "width"
QT_MOC_LITERAL(8, 104, 15), // "axisXTopChanged"
QT_MOC_LITERAL(9, 120, 17), // "axisYRightChanged"
QT_MOC_LITERAL(10, 138, 18), // "axisAngularChanged"
QT_MOC_LITERAL(11, 157, 17), // "axisRadialChanged"
QT_MOC_LITERAL(12, 175, 12), // "brushChanged"
QT_MOC_LITERAL(13, 188, 20), // "brushFilenameChanged"
QT_MOC_LITERAL(14, 209, 13), // "brushFilename"
QT_MOC_LITERAL(15, 223, 18), // "handleBrushChanged"
QT_MOC_LITERAL(16, 242, 11), // "upperSeries"
QT_MOC_LITERAL(17, 254, 32), // "QtCharts::DeclarativeLineSeries*"
QT_MOC_LITERAL(18, 287, 11), // "lowerSeries"
QT_MOC_LITERAL(19, 299, 5), // "axisX"
QT_MOC_LITERAL(20, 305, 24), // "QtCharts::QAbstractAxis*"
QT_MOC_LITERAL(21, 330, 5), // "axisY"
QT_MOC_LITERAL(22, 336, 8), // "axisXTop"
QT_MOC_LITERAL(23, 345, 10), // "axisYRight"
QT_MOC_LITERAL(24, 356, 11), // "axisAngular"
QT_MOC_LITERAL(25, 368, 10), // "axisRadial"
QT_MOC_LITERAL(26, 379, 11), // "borderWidth"
QT_MOC_LITERAL(27, 391, 5) // "brush"

    },
    "QtCharts::DeclarativeAreaSeries\0"
    "axisXChanged\0\0QAbstractAxis*\0axis\0"
    "axisYChanged\0borderWidthChanged\0width\0"
    "axisXTopChanged\0axisYRightChanged\0"
    "axisAngularChanged\0axisRadialChanged\0"
    "brushChanged\0brushFilenameChanged\0"
    "brushFilename\0handleBrushChanged\0"
    "upperSeries\0QtCharts::DeclarativeLineSeries*\0"
    "lowerSeries\0axisX\0QtCharts::QAbstractAxis*\0"
    "axisY\0axisXTop\0axisYRight\0axisAngular\0"
    "axisRadial\0borderWidth\0brush"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__DeclarativeAreaSeries[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
      11,  100, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x86 /* Public | MethodRevisioned */,
       5,    1,   77,    2, 0x86 /* Public | MethodRevisioned */,
       6,    1,   80,    2, 0x86 /* Public | MethodRevisioned */,
       8,    1,   83,    2, 0x86 /* Public | MethodRevisioned */,
       9,    1,   86,    2, 0x86 /* Public | MethodRevisioned */,
      10,    1,   89,    2, 0x86 /* Public | MethodRevisioned */,
      11,    1,   92,    2, 0x86 /* Public | MethodRevisioned */,
      12,    0,   95,    2, 0x86 /* Public | MethodRevisioned */,
      13,    1,   96,    2, 0x86 /* Public | MethodRevisioned */,

 // slots: name, argc, parameters, tag, flags
      15,    0,   99,    2, 0x08 /* Private */,

 // signals: revision
       1,
       1,
       1,
       2,
       2,
       3,
       3,
       4,
       4,

 // slots: revision
       0,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::QReal,    7,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   14,

 // slots: parameters
    QMetaType::Void,

 // properties: name, type, flags
      16, 0x80000000 | 17, 0x0009510b,
      18, 0x80000000 | 17, 0x0009510b,
      19, 0x80000000 | 20, 0x00c9510b,
      21, 0x80000000 | 20, 0x00c9510b,
      22, 0x80000000 | 20, 0x00c9510b,
      23, 0x80000000 | 20, 0x00c9510b,
      24, 0x80000000 | 20, 0x00c9510b,
      25, 0x80000000 | 20, 0x00c9510b,
      26, QMetaType::QReal, 0x00c95103,
      14, QMetaType::QString, 0x00c95103,
      27, QMetaType::QBrush, 0x00c95103,

 // properties: notify_signal_id
       0,
       0,
       0,
       1,
       3,
       4,
       5,
       6,
       2,
       8,
       7,

 // properties: revision
       0,
       0,
       1,
       1,
       2,
       2,
       3,
       3,
       1,
       4,
       4,

       0        // eod
};

void QtCharts::DeclarativeAreaSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DeclarativeAreaSeries *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->axisXChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 1: _t->axisYChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 2: _t->borderWidthChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 3: _t->axisXTopChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 4: _t->axisYRightChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 5: _t->axisAngularChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 6: _t->axisRadialChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 7: _t->brushChanged(); break;
        case 8: _t->brushFilenameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->handleBrushChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DeclarativeAreaSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::axisXChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::axisYChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::borderWidthChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::axisXTopChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::axisYRightChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::axisAngularChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::axisRadialChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::brushChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DeclarativeAreaSeries::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeAreaSeries::brushFilenameChanged)) {
                *result = 8;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtCharts::QAbstractAxis* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DeclarativeAreaSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QtCharts::DeclarativeLineSeries**>(_v) = _t->upperSeries(); break;
        case 1: *reinterpret_cast< QtCharts::DeclarativeLineSeries**>(_v) = _t->lowerSeries(); break;
        case 2: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisX(); break;
        case 3: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisY(); break;
        case 4: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 5: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 6: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisAngular(); break;
        case 7: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisRadial(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->borderWidth(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->brushFilename(); break;
        case 10: *reinterpret_cast< QBrush*>(_v) = _t->brush(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DeclarativeAreaSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setUpperSeries(*reinterpret_cast< QtCharts::DeclarativeLineSeries**>(_v)); break;
        case 1: _t->setLowerSeries(*reinterpret_cast< QtCharts::DeclarativeLineSeries**>(_v)); break;
        case 2: _t->setAxisX(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisY(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 4: _t->setAxisXTop(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 5: _t->setAxisYRight(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 6: _t->setAxisAngular(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 7: _t->setAxisRadial(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 8: _t->setBorderWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 9: _t->setBrushFilename(*reinterpret_cast< QString*>(_v)); break;
        case 10: _t->setBrush(*reinterpret_cast< QBrush*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::DeclarativeAreaSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QAreaSeries::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__DeclarativeAreaSeries.data,
    qt_meta_data_QtCharts__DeclarativeAreaSeries,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::DeclarativeAreaSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::DeclarativeAreaSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__DeclarativeAreaSeries.stringdata0))
        return static_cast<void*>(this);
    return QAreaSeries::qt_metacast(_clname);
}

int QtCharts::DeclarativeAreaSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAreaSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::DeclarativeAreaSeries::axisXChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::DeclarativeAreaSeries::axisYChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::DeclarativeAreaSeries::borderWidthChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::DeclarativeAreaSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::DeclarativeAreaSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::DeclarativeAreaSeries::axisAngularChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QtCharts::DeclarativeAreaSeries::axisRadialChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QtCharts::DeclarativeAreaSeries::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QtCharts::DeclarativeAreaSeries::brushFilenameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
