/****************************************************************************
** Meta object code from reading C++ file 'qcandlestickseries.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/candlestickchart/qcandlestickseries.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qcandlestickseries.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QCandlestickSeries_t {
    QByteArrayData data[36];
    char stringdata0[535];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QCandlestickSeries_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QCandlestickSeries_t qt_meta_stringdata_QtCharts__QCandlestickSeries = {
    {
QT_MOC_LITERAL(0, 0, 28), // "QtCharts::QCandlestickSeries"
QT_MOC_LITERAL(1, 29, 7), // "clicked"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 16), // "QCandlestickSet*"
QT_MOC_LITERAL(4, 55, 3), // "set"
QT_MOC_LITERAL(5, 59, 7), // "hovered"
QT_MOC_LITERAL(6, 67, 6), // "status"
QT_MOC_LITERAL(7, 74, 7), // "pressed"
QT_MOC_LITERAL(8, 82, 8), // "released"
QT_MOC_LITERAL(9, 91, 13), // "doubleClicked"
QT_MOC_LITERAL(10, 105, 20), // "candlestickSetsAdded"
QT_MOC_LITERAL(11, 126, 23), // "QList<QCandlestickSet*>"
QT_MOC_LITERAL(12, 150, 4), // "sets"
QT_MOC_LITERAL(13, 155, 22), // "candlestickSetsRemoved"
QT_MOC_LITERAL(14, 178, 12), // "countChanged"
QT_MOC_LITERAL(15, 191, 25), // "maximumColumnWidthChanged"
QT_MOC_LITERAL(16, 217, 25), // "minimumColumnWidthChanged"
QT_MOC_LITERAL(17, 243, 16), // "bodyWidthChanged"
QT_MOC_LITERAL(18, 260, 28), // "bodyOutlineVisibilityChanged"
QT_MOC_LITERAL(19, 289, 16), // "capsWidthChanged"
QT_MOC_LITERAL(20, 306, 21), // "capsVisibilityChanged"
QT_MOC_LITERAL(21, 328, 22), // "increasingColorChanged"
QT_MOC_LITERAL(22, 351, 22), // "decreasingColorChanged"
QT_MOC_LITERAL(23, 374, 12), // "brushChanged"
QT_MOC_LITERAL(24, 387, 10), // "penChanged"
QT_MOC_LITERAL(25, 398, 5), // "count"
QT_MOC_LITERAL(26, 404, 18), // "maximumColumnWidth"
QT_MOC_LITERAL(27, 423, 18), // "minimumColumnWidth"
QT_MOC_LITERAL(28, 442, 9), // "bodyWidth"
QT_MOC_LITERAL(29, 452, 18), // "bodyOutlineVisible"
QT_MOC_LITERAL(30, 471, 9), // "capsWidth"
QT_MOC_LITERAL(31, 481, 11), // "capsVisible"
QT_MOC_LITERAL(32, 493, 15), // "increasingColor"
QT_MOC_LITERAL(33, 509, 15), // "decreasingColor"
QT_MOC_LITERAL(34, 525, 5), // "brush"
QT_MOC_LITERAL(35, 531, 3) // "pen"

    },
    "QtCharts::QCandlestickSeries\0clicked\0"
    "\0QCandlestickSet*\0set\0hovered\0status\0"
    "pressed\0released\0doubleClicked\0"
    "candlestickSetsAdded\0QList<QCandlestickSet*>\0"
    "sets\0candlestickSetsRemoved\0countChanged\0"
    "maximumColumnWidthChanged\0"
    "minimumColumnWidthChanged\0bodyWidthChanged\0"
    "bodyOutlineVisibilityChanged\0"
    "capsWidthChanged\0capsVisibilityChanged\0"
    "increasingColorChanged\0decreasingColorChanged\0"
    "brushChanged\0penChanged\0count\0"
    "maximumColumnWidth\0minimumColumnWidth\0"
    "bodyWidth\0bodyOutlineVisible\0capsWidth\0"
    "capsVisible\0increasingColor\0decreasingColor\0"
    "brush\0pen"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QCandlestickSeries[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      18,   14, // methods
      11,  138, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  104,    2, 0x06 /* Public */,
       5,    2,  107,    2, 0x06 /* Public */,
       7,    1,  112,    2, 0x06 /* Public */,
       8,    1,  115,    2, 0x06 /* Public */,
       9,    1,  118,    2, 0x06 /* Public */,
      10,    1,  121,    2, 0x06 /* Public */,
      13,    1,  124,    2, 0x06 /* Public */,
      14,    0,  127,    2, 0x06 /* Public */,
      15,    0,  128,    2, 0x06 /* Public */,
      16,    0,  129,    2, 0x06 /* Public */,
      17,    0,  130,    2, 0x06 /* Public */,
      18,    0,  131,    2, 0x06 /* Public */,
      19,    0,  132,    2, 0x06 /* Public */,
      20,    0,  133,    2, 0x06 /* Public */,
      21,    0,  134,    2, 0x06 /* Public */,
      22,    0,  135,    2, 0x06 /* Public */,
      23,    0,  136,    2, 0x06 /* Public */,
      24,    0,  137,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Bool, 0x80000000 | 3,    6,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void, 0x80000000 | 11,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      25, QMetaType::Int, 0x00495001,
      26, QMetaType::QReal, 0x00495103,
      27, QMetaType::QReal, 0x00495103,
      28, QMetaType::QReal, 0x00495103,
      29, QMetaType::Bool, 0x00495103,
      30, QMetaType::QReal, 0x00495103,
      31, QMetaType::Bool, 0x00495103,
      32, QMetaType::QColor, 0x00495103,
      33, QMetaType::QColor, 0x00495103,
      34, QMetaType::QBrush, 0x00495103,
      35, QMetaType::QPen, 0x00495103,

 // properties: notify_signal_id
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
      15,
      16,
      17,

       0        // eod
};

void QtCharts::QCandlestickSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QCandlestickSeries *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< QCandlestickSet*(*)>(_a[1]))); break;
        case 1: _t->hovered((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< QCandlestickSet*(*)>(_a[2]))); break;
        case 2: _t->pressed((*reinterpret_cast< QCandlestickSet*(*)>(_a[1]))); break;
        case 3: _t->released((*reinterpret_cast< QCandlestickSet*(*)>(_a[1]))); break;
        case 4: _t->doubleClicked((*reinterpret_cast< QCandlestickSet*(*)>(_a[1]))); break;
        case 5: _t->candlestickSetsAdded((*reinterpret_cast< const QList<QCandlestickSet*>(*)>(_a[1]))); break;
        case 6: _t->candlestickSetsRemoved((*reinterpret_cast< const QList<QCandlestickSet*>(*)>(_a[1]))); break;
        case 7: _t->countChanged(); break;
        case 8: _t->maximumColumnWidthChanged(); break;
        case 9: _t->minimumColumnWidthChanged(); break;
        case 10: _t->bodyWidthChanged(); break;
        case 11: _t->bodyOutlineVisibilityChanged(); break;
        case 12: _t->capsWidthChanged(); break;
        case 13: _t->capsVisibilityChanged(); break;
        case 14: _t->increasingColorChanged(); break;
        case 15: _t->decreasingColorChanged(); break;
        case 16: _t->brushChanged(); break;
        case 17: _t->penChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QCandlestickSeries::*)(QCandlestickSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)(bool , QCandlestickSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::hovered)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)(QCandlestickSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::pressed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)(QCandlestickSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::released)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)(QCandlestickSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::doubleClicked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)(const QList<QCandlestickSet*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::candlestickSetsAdded)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)(const QList<QCandlestickSet*> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::candlestickSetsRemoved)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::countChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::maximumColumnWidthChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::minimumColumnWidthChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::bodyWidthChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::bodyOutlineVisibilityChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::capsWidthChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::capsVisibilityChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::increasingColorChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::decreasingColorChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::brushChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (QCandlestickSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QCandlestickSeries::penChanged)) {
                *result = 17;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QCandlestickSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->maximumColumnWidth(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->minimumColumnWidth(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->bodyWidth(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->bodyOutlineVisible(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->capsWidth(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->capsVisible(); break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->increasingColor(); break;
        case 8: *reinterpret_cast< QColor*>(_v) = _t->decreasingColor(); break;
        case 9: *reinterpret_cast< QBrush*>(_v) = _t->brush(); break;
        case 10: *reinterpret_cast< QPen*>(_v) = _t->pen(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QCandlestickSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setMaximumColumnWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setMinimumColumnWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setBodyWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 4: _t->setBodyOutlineVisible(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setCapsWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 6: _t->setCapsVisible(*reinterpret_cast< bool*>(_v)); break;
        case 7: _t->setIncreasingColor(*reinterpret_cast< QColor*>(_v)); break;
        case 8: _t->setDecreasingColor(*reinterpret_cast< QColor*>(_v)); break;
        case 9: _t->setBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 10: _t->setPen(*reinterpret_cast< QPen*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QCandlestickSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractSeries::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QCandlestickSeries.data,
    qt_meta_data_QtCharts__QCandlestickSeries,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QCandlestickSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QCandlestickSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QCandlestickSeries.stringdata0))
        return static_cast<void*>(this);
    return QAbstractSeries::qt_metacast(_clname);
}

int QtCharts::QCandlestickSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 18;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QCandlestickSeries::clicked(QCandlestickSet * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::QCandlestickSeries::hovered(bool _t1, QCandlestickSet * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QCandlestickSeries::pressed(QCandlestickSet * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::QCandlestickSeries::released(QCandlestickSet * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::QCandlestickSeries::doubleClicked(QCandlestickSet * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::QCandlestickSeries::candlestickSetsAdded(const QList<QCandlestickSet*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QtCharts::QCandlestickSeries::candlestickSetsRemoved(const QList<QCandlestickSet*> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QtCharts::QCandlestickSeries::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QtCharts::QCandlestickSeries::maximumColumnWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QtCharts::QCandlestickSeries::minimumColumnWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QtCharts::QCandlestickSeries::bodyWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QtCharts::QCandlestickSeries::bodyOutlineVisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QtCharts::QCandlestickSeries::capsWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QtCharts::QCandlestickSeries::capsVisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QtCharts::QCandlestickSeries::increasingColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QtCharts::QCandlestickSeries::decreasingColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QtCharts::QCandlestickSeries::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QtCharts::QCandlestickSeries::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
