/****************************************************************************
** Meta object code from reading C++ file 'chartaxiselement_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/axis/chartaxiselement_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'chartaxiselement_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__ChartAxisElement_t {
    QByteArrayData data[44];
    char stringdata0[792];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__ChartAxisElement_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__ChartAxisElement_t qt_meta_stringdata_QtCharts__ChartAxisElement = {
    {
QT_MOC_LITERAL(0, 0, 26), // "QtCharts::ChartAxisElement"
QT_MOC_LITERAL(1, 27, 7), // "clicked"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 20), // "handleVisibleChanged"
QT_MOC_LITERAL(4, 57, 7), // "visible"
QT_MOC_LITERAL(5, 65, 25), // "handleArrowVisibleChanged"
QT_MOC_LITERAL(6, 91, 24), // "handleGridVisibleChanged"
QT_MOC_LITERAL(7, 116, 26), // "handleLabelsVisibleChanged"
QT_MOC_LITERAL(8, 143, 26), // "handleShadesVisibleChanged"
QT_MOC_LITERAL(9, 170, 24), // "handleLabelsAngleChanged"
QT_MOC_LITERAL(10, 195, 5), // "angle"
QT_MOC_LITERAL(11, 201, 24), // "handleShadesBrushChanged"
QT_MOC_LITERAL(12, 226, 5), // "brush"
QT_MOC_LITERAL(13, 232, 22), // "handleShadesPenChanged"
QT_MOC_LITERAL(14, 255, 3), // "pen"
QT_MOC_LITERAL(15, 259, 21), // "handleArrowPenChanged"
QT_MOC_LITERAL(16, 281, 20), // "handleGridPenChanged"
QT_MOC_LITERAL(17, 302, 26), // "handleMinorArrowPenChanged"
QT_MOC_LITERAL(18, 329, 25), // "handleMinorGridPenChanged"
QT_MOC_LITERAL(19, 355, 31), // "handleMinorGridLineColorChanged"
QT_MOC_LITERAL(20, 387, 5), // "color"
QT_MOC_LITERAL(21, 393, 26), // "handleGridLineColorChanged"
QT_MOC_LITERAL(22, 420, 24), // "handleLabelsBrushChanged"
QT_MOC_LITERAL(23, 445, 23), // "handleLabelsFontChanged"
QT_MOC_LITERAL(24, 469, 4), // "font"
QT_MOC_LITERAL(25, 474, 23), // "handleTitleBrushChanged"
QT_MOC_LITERAL(26, 498, 22), // "handleTitleFontChanged"
QT_MOC_LITERAL(27, 521, 22), // "handleTitleTextChanged"
QT_MOC_LITERAL(28, 544, 5), // "title"
QT_MOC_LITERAL(29, 550, 25), // "handleTitleVisibleChanged"
QT_MOC_LITERAL(30, 576, 18), // "handleRangeChanged"
QT_MOC_LITERAL(31, 595, 3), // "min"
QT_MOC_LITERAL(32, 599, 3), // "max"
QT_MOC_LITERAL(33, 603, 20), // "handleReverseChanged"
QT_MOC_LITERAL(34, 624, 7), // "reverse"
QT_MOC_LITERAL(35, 632, 30), // "handleMinorArrowVisibleChanged"
QT_MOC_LITERAL(36, 663, 29), // "handleMinorGridVisibleChanged"
QT_MOC_LITERAL(37, 693, 27), // "handleLabelsPositionChanged"
QT_MOC_LITERAL(38, 721, 16), // "valueLabelEdited"
QT_MOC_LITERAL(39, 738, 8), // "oldValue"
QT_MOC_LITERAL(40, 747, 8), // "newValue"
QT_MOC_LITERAL(41, 756, 19), // "dateTimeLabelEdited"
QT_MOC_LITERAL(42, 776, 7), // "oldTime"
QT_MOC_LITERAL(43, 784, 7) // "newTime"

    },
    "QtCharts::ChartAxisElement\0clicked\0\0"
    "handleVisibleChanged\0visible\0"
    "handleArrowVisibleChanged\0"
    "handleGridVisibleChanged\0"
    "handleLabelsVisibleChanged\0"
    "handleShadesVisibleChanged\0"
    "handleLabelsAngleChanged\0angle\0"
    "handleShadesBrushChanged\0brush\0"
    "handleShadesPenChanged\0pen\0"
    "handleArrowPenChanged\0handleGridPenChanged\0"
    "handleMinorArrowPenChanged\0"
    "handleMinorGridPenChanged\0"
    "handleMinorGridLineColorChanged\0color\0"
    "handleGridLineColorChanged\0"
    "handleLabelsBrushChanged\0"
    "handleLabelsFontChanged\0font\0"
    "handleTitleBrushChanged\0handleTitleFontChanged\0"
    "handleTitleTextChanged\0title\0"
    "handleTitleVisibleChanged\0handleRangeChanged\0"
    "min\0max\0handleReverseChanged\0reverse\0"
    "handleMinorArrowVisibleChanged\0"
    "handleMinorGridVisibleChanged\0"
    "handleLabelsPositionChanged\0"
    "valueLabelEdited\0oldValue\0newValue\0"
    "dateTimeLabelEdited\0oldTime\0newTime"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__ChartAxisElement[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  154,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  155,    2, 0x0a /* Public */,
       5,    1,  158,    2, 0x0a /* Public */,
       6,    1,  161,    2, 0x0a /* Public */,
       7,    1,  164,    2, 0x0a /* Public */,
       8,    1,  167,    2, 0x0a /* Public */,
       9,    1,  170,    2, 0x0a /* Public */,
      11,    1,  173,    2, 0x0a /* Public */,
      13,    1,  176,    2, 0x0a /* Public */,
      15,    1,  179,    2, 0x0a /* Public */,
      16,    1,  182,    2, 0x0a /* Public */,
      17,    1,  185,    2, 0x0a /* Public */,
      18,    1,  188,    2, 0x0a /* Public */,
      19,    1,  191,    2, 0x0a /* Public */,
      21,    1,  194,    2, 0x0a /* Public */,
      22,    1,  197,    2, 0x0a /* Public */,
      23,    1,  200,    2, 0x0a /* Public */,
      25,    1,  203,    2, 0x0a /* Public */,
      26,    1,  206,    2, 0x0a /* Public */,
      27,    1,  209,    2, 0x0a /* Public */,
      29,    1,  212,    2, 0x0a /* Public */,
      30,    2,  215,    2, 0x0a /* Public */,
      33,    1,  220,    2, 0x0a /* Public */,
      35,    1,  223,    2, 0x0a /* Public */,
      36,    1,  226,    2, 0x0a /* Public */,
      37,    0,  229,    2, 0x0a /* Public */,
      38,    2,  230,    2, 0x0a /* Public */,
      41,    2,  235,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::QBrush,   12,
    QMetaType::Void, QMetaType::QPen,   14,
    QMetaType::Void, QMetaType::QPen,   14,
    QMetaType::Void, QMetaType::QPen,   14,
    QMetaType::Void, QMetaType::QPen,   14,
    QMetaType::Void, QMetaType::QPen,   14,
    QMetaType::Void, QMetaType::QColor,   20,
    QMetaType::Void, QMetaType::QColor,   20,
    QMetaType::Void, QMetaType::QBrush,   12,
    QMetaType::Void, QMetaType::QFont,   24,
    QMetaType::Void, QMetaType::QBrush,   12,
    QMetaType::Void, QMetaType::QFont,   24,
    QMetaType::Void, QMetaType::QString,   28,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   31,   32,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   39,   40,
    QMetaType::Void, QMetaType::QDateTime, QMetaType::QDateTime,   42,   43,

       0        // eod
};

void QtCharts::ChartAxisElement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ChartAxisElement *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->handleVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->handleArrowVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->handleGridVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->handleLabelsVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->handleShadesVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->handleLabelsAngleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->handleShadesBrushChanged((*reinterpret_cast< const QBrush(*)>(_a[1]))); break;
        case 8: _t->handleShadesPenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 9: _t->handleArrowPenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 10: _t->handleGridPenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 11: _t->handleMinorArrowPenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 12: _t->handleMinorGridPenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 13: _t->handleMinorGridLineColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 14: _t->handleGridLineColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 15: _t->handleLabelsBrushChanged((*reinterpret_cast< const QBrush(*)>(_a[1]))); break;
        case 16: _t->handleLabelsFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 17: _t->handleTitleBrushChanged((*reinterpret_cast< const QBrush(*)>(_a[1]))); break;
        case 18: _t->handleTitleFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 19: _t->handleTitleTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->handleTitleVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: _t->handleRangeChanged((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 22: _t->handleReverseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->handleMinorArrowVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->handleMinorGridVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->handleLabelsPositionChanged(); break;
        case 26: _t->valueLabelEdited((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 27: _t->dateTimeLabelEdited((*reinterpret_cast< const QDateTime(*)>(_a[1])),(*reinterpret_cast< const QDateTime(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ChartAxisElement::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ChartAxisElement::clicked)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::ChartAxisElement::staticMetaObject = { {
    QMetaObject::SuperData::link<ChartElement::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__ChartAxisElement.data,
    qt_meta_data_QtCharts__ChartAxisElement,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::ChartAxisElement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::ChartAxisElement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__ChartAxisElement.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QGraphicsLayoutItem"))
        return static_cast< QGraphicsLayoutItem*>(this);
    return ChartElement::qt_metacast(_clname);
}

int QtCharts::ChartAxisElement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ChartElement::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void QtCharts::ChartAxisElement::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
