/****************************************************************************
** Meta object code from reading C++ file 'declarativechart_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/chartsqml2/declarativechart_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativechart_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__DeclarativeChart_t {
    QByteArrayData data[121];
    char stringdata0[1728];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__DeclarativeChart_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__DeclarativeChart_t qt_meta_stringdata_QtCharts__DeclarativeChart = {
    {
QT_MOC_LITERAL(0, 0, 26), // "QtCharts::DeclarativeChart"
QT_MOC_LITERAL(1, 27, 17), // "axisLabelsChanged"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 17), // "titleColorChanged"
QT_MOC_LITERAL(4, 64, 5), // "color"
QT_MOC_LITERAL(5, 70, 22), // "backgroundColorChanged"
QT_MOC_LITERAL(6, 93, 24), // "dropShadowEnabledChanged"
QT_MOC_LITERAL(7, 118, 7), // "enabled"
QT_MOC_LITERAL(8, 126, 14), // "marginsChanged"
QT_MOC_LITERAL(9, 141, 15), // "plotAreaChanged"
QT_MOC_LITERAL(10, 157, 8), // "plotArea"
QT_MOC_LITERAL(11, 166, 11), // "seriesAdded"
QT_MOC_LITERAL(12, 178, 16), // "QAbstractSeries*"
QT_MOC_LITERAL(13, 195, 6), // "series"
QT_MOC_LITERAL(14, 202, 13), // "seriesRemoved"
QT_MOC_LITERAL(15, 216, 20), // "plotAreaColorChanged"
QT_MOC_LITERAL(16, 237, 26), // "backgroundRoundnessChanged"
QT_MOC_LITERAL(17, 264, 8), // "diameter"
QT_MOC_LITERAL(18, 273, 22), // "localizeNumbersChanged"
QT_MOC_LITERAL(19, 296, 13), // "localeChanged"
QT_MOC_LITERAL(20, 310, 24), // "animationDurationChanged"
QT_MOC_LITERAL(21, 335, 5), // "msecs"
QT_MOC_LITERAL(22, 341, 27), // "animationEasingCurveChanged"
QT_MOC_LITERAL(23, 369, 12), // "QEasingCurve"
QT_MOC_LITERAL(24, 382, 5), // "curve"
QT_MOC_LITERAL(25, 388, 10), // "needRender"
QT_MOC_LITERAL(26, 399, 36), // "pendingRenderNodeMouseEventRe..."
QT_MOC_LITERAL(27, 436, 25), // "handleAntialiasingChanged"
QT_MOC_LITERAL(28, 462, 6), // "enable"
QT_MOC_LITERAL(29, 469, 12), // "sceneChanged"
QT_MOC_LITERAL(30, 482, 13), // "QList<QRectF>"
QT_MOC_LITERAL(31, 496, 6), // "region"
QT_MOC_LITERAL(32, 503, 11), // "renderScene"
QT_MOC_LITERAL(33, 515, 13), // "changeMargins"
QT_MOC_LITERAL(34, 529, 3), // "top"
QT_MOC_LITERAL(35, 533, 6), // "bottom"
QT_MOC_LITERAL(36, 540, 4), // "left"
QT_MOC_LITERAL(37, 545, 5), // "right"
QT_MOC_LITERAL(38, 551, 14), // "handleAxisXSet"
QT_MOC_LITERAL(39, 566, 14), // "QAbstractAxis*"
QT_MOC_LITERAL(40, 581, 4), // "axis"
QT_MOC_LITERAL(41, 586, 14), // "handleAxisYSet"
QT_MOC_LITERAL(42, 601, 17), // "handleAxisXTopSet"
QT_MOC_LITERAL(43, 619, 19), // "handleAxisYRightSet"
QT_MOC_LITERAL(44, 639, 17), // "handleSeriesAdded"
QT_MOC_LITERAL(45, 657, 42), // "handlePendingRenderNodeMouseE..."
QT_MOC_LITERAL(46, 700, 5), // "index"
QT_MOC_LITERAL(47, 706, 10), // "seriesName"
QT_MOC_LITERAL(48, 717, 12), // "createSeries"
QT_MOC_LITERAL(49, 730, 4), // "type"
QT_MOC_LITERAL(50, 735, 4), // "name"
QT_MOC_LITERAL(51, 740, 5), // "axisX"
QT_MOC_LITERAL(52, 746, 5), // "axisY"
QT_MOC_LITERAL(53, 752, 12), // "removeSeries"
QT_MOC_LITERAL(54, 765, 15), // "removeAllSeries"
QT_MOC_LITERAL(55, 781, 8), // "setAxisX"
QT_MOC_LITERAL(56, 790, 8), // "setAxisY"
QT_MOC_LITERAL(57, 799, 4), // "zoom"
QT_MOC_LITERAL(58, 804, 6), // "factor"
QT_MOC_LITERAL(59, 811, 6), // "zoomIn"
QT_MOC_LITERAL(60, 818, 9), // "rectangle"
QT_MOC_LITERAL(61, 828, 7), // "zoomOut"
QT_MOC_LITERAL(62, 836, 9), // "zoomReset"
QT_MOC_LITERAL(63, 846, 8), // "isZoomed"
QT_MOC_LITERAL(64, 855, 10), // "scrollLeft"
QT_MOC_LITERAL(65, 866, 6), // "pixels"
QT_MOC_LITERAL(66, 873, 11), // "scrollRight"
QT_MOC_LITERAL(67, 885, 8), // "scrollUp"
QT_MOC_LITERAL(68, 894, 10), // "scrollDown"
QT_MOC_LITERAL(69, 905, 10), // "mapToValue"
QT_MOC_LITERAL(70, 916, 8), // "position"
QT_MOC_LITERAL(71, 925, 13), // "mapToPosition"
QT_MOC_LITERAL(72, 939, 5), // "value"
QT_MOC_LITERAL(73, 945, 5), // "theme"
QT_MOC_LITERAL(74, 951, 5), // "Theme"
QT_MOC_LITERAL(75, 957, 16), // "animationOptions"
QT_MOC_LITERAL(76, 974, 9), // "Animation"
QT_MOC_LITERAL(77, 984, 17), // "animationDuration"
QT_MOC_LITERAL(78, 1002, 20), // "animationEasingCurve"
QT_MOC_LITERAL(79, 1023, 5), // "title"
QT_MOC_LITERAL(80, 1029, 9), // "titleFont"
QT_MOC_LITERAL(81, 1039, 10), // "titleColor"
QT_MOC_LITERAL(82, 1050, 6), // "legend"
QT_MOC_LITERAL(83, 1057, 18), // "QtCharts::QLegend*"
QT_MOC_LITERAL(84, 1076, 5), // "count"
QT_MOC_LITERAL(85, 1082, 15), // "backgroundColor"
QT_MOC_LITERAL(86, 1098, 17), // "dropShadowEnabled"
QT_MOC_LITERAL(87, 1116, 19), // "backgroundRoundness"
QT_MOC_LITERAL(88, 1136, 7), // "margins"
QT_MOC_LITERAL(89, 1144, 29), // "QtCharts::DeclarativeMargins*"
QT_MOC_LITERAL(90, 1174, 13), // "plotAreaColor"
QT_MOC_LITERAL(91, 1188, 4), // "axes"
QT_MOC_LITERAL(92, 1193, 31), // "QQmlListProperty<QAbstractAxis>"
QT_MOC_LITERAL(93, 1225, 15), // "localizeNumbers"
QT_MOC_LITERAL(94, 1241, 6), // "locale"
QT_MOC_LITERAL(95, 1248, 15), // "ChartThemeLight"
QT_MOC_LITERAL(96, 1264, 22), // "ChartThemeBlueCerulean"
QT_MOC_LITERAL(97, 1287, 14), // "ChartThemeDark"
QT_MOC_LITERAL(98, 1302, 19), // "ChartThemeBrownSand"
QT_MOC_LITERAL(99, 1322, 17), // "ChartThemeBlueNcs"
QT_MOC_LITERAL(100, 1340, 22), // "ChartThemeHighContrast"
QT_MOC_LITERAL(101, 1363, 17), // "ChartThemeBlueIcy"
QT_MOC_LITERAL(102, 1381, 12), // "ChartThemeQt"
QT_MOC_LITERAL(103, 1394, 11), // "NoAnimation"
QT_MOC_LITERAL(104, 1406, 18), // "GridAxisAnimations"
QT_MOC_LITERAL(105, 1425, 16), // "SeriesAnimations"
QT_MOC_LITERAL(106, 1442, 13), // "AllAnimations"
QT_MOC_LITERAL(107, 1456, 10), // "SeriesType"
QT_MOC_LITERAL(108, 1467, 14), // "SeriesTypeLine"
QT_MOC_LITERAL(109, 1482, 14), // "SeriesTypeArea"
QT_MOC_LITERAL(110, 1497, 13), // "SeriesTypeBar"
QT_MOC_LITERAL(111, 1511, 20), // "SeriesTypeStackedBar"
QT_MOC_LITERAL(112, 1532, 20), // "SeriesTypePercentBar"
QT_MOC_LITERAL(113, 1553, 13), // "SeriesTypePie"
QT_MOC_LITERAL(114, 1567, 17), // "SeriesTypeScatter"
QT_MOC_LITERAL(115, 1585, 16), // "SeriesTypeSpline"
QT_MOC_LITERAL(116, 1602, 23), // "SeriesTypeHorizontalBar"
QT_MOC_LITERAL(117, 1626, 30), // "SeriesTypeHorizontalStackedBar"
QT_MOC_LITERAL(118, 1657, 30), // "SeriesTypeHorizontalPercentBar"
QT_MOC_LITERAL(119, 1688, 17), // "SeriesTypeBoxPlot"
QT_MOC_LITERAL(120, 1706, 21) // "SeriesTypeCandlestick"

    },
    "QtCharts::DeclarativeChart\0axisLabelsChanged\0"
    "\0titleColorChanged\0color\0"
    "backgroundColorChanged\0dropShadowEnabledChanged\0"
    "enabled\0marginsChanged\0plotAreaChanged\0"
    "plotArea\0seriesAdded\0QAbstractSeries*\0"
    "series\0seriesRemoved\0plotAreaColorChanged\0"
    "backgroundRoundnessChanged\0diameter\0"
    "localizeNumbersChanged\0localeChanged\0"
    "animationDurationChanged\0msecs\0"
    "animationEasingCurveChanged\0QEasingCurve\0"
    "curve\0needRender\0pendingRenderNodeMouseEventResponses\0"
    "handleAntialiasingChanged\0enable\0"
    "sceneChanged\0QList<QRectF>\0region\0"
    "renderScene\0changeMargins\0top\0bottom\0"
    "left\0right\0handleAxisXSet\0QAbstractAxis*\0"
    "axis\0handleAxisYSet\0handleAxisXTopSet\0"
    "handleAxisYRightSet\0handleSeriesAdded\0"
    "handlePendingRenderNodeMouseEventResponses\0"
    "index\0seriesName\0createSeries\0type\0"
    "name\0axisX\0axisY\0removeSeries\0"
    "removeAllSeries\0setAxisX\0setAxisY\0"
    "zoom\0factor\0zoomIn\0rectangle\0zoomOut\0"
    "zoomReset\0isZoomed\0scrollLeft\0pixels\0"
    "scrollRight\0scrollUp\0scrollDown\0"
    "mapToValue\0position\0mapToPosition\0"
    "value\0theme\0Theme\0animationOptions\0"
    "Animation\0animationDuration\0"
    "animationEasingCurve\0title\0titleFont\0"
    "titleColor\0legend\0QtCharts::QLegend*\0"
    "count\0backgroundColor\0dropShadowEnabled\0"
    "backgroundRoundness\0margins\0"
    "QtCharts::DeclarativeMargins*\0"
    "plotAreaColor\0axes\0QQmlListProperty<QAbstractAxis>\0"
    "localizeNumbers\0locale\0ChartThemeLight\0"
    "ChartThemeBlueCerulean\0ChartThemeDark\0"
    "ChartThemeBrownSand\0ChartThemeBlueNcs\0"
    "ChartThemeHighContrast\0ChartThemeBlueIcy\0"
    "ChartThemeQt\0NoAnimation\0GridAxisAnimations\0"
    "SeriesAnimations\0AllAnimations\0"
    "SeriesType\0SeriesTypeLine\0SeriesTypeArea\0"
    "SeriesTypeBar\0SeriesTypeStackedBar\0"
    "SeriesTypePercentBar\0SeriesTypePie\0"
    "SeriesTypeScatter\0SeriesTypeSpline\0"
    "SeriesTypeHorizontalBar\0"
    "SeriesTypeHorizontalStackedBar\0"
    "SeriesTypeHorizontalPercentBar\0"
    "SeriesTypeBoxPlot\0SeriesTypeCandlestick"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__DeclarativeChart[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      56,   14, // methods
      18,  510, // properties
       3,  600, // enums/sets
       0,    0, // constructors
       0,       // flags
      16,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  350,    2, 0x06 /* Public */,
       3,    1,  351,    2, 0x06 /* Public */,
       5,    0,  354,    2, 0x06 /* Public */,
       6,    1,  355,    2, 0x06 /* Public */,
       8,    0,  358,    2, 0x86 /* Public | MethodRevisioned */,
       9,    1,  359,    2, 0x06 /* Public */,
      11,    1,  362,    2, 0x06 /* Public */,
      14,    1,  365,    2, 0x06 /* Public */,
      15,    0,  368,    2, 0x86 /* Public | MethodRevisioned */,
      16,    1,  369,    2, 0x86 /* Public | MethodRevisioned */,
      18,    0,  372,    2, 0x86 /* Public | MethodRevisioned */,
      19,    0,  373,    2, 0x86 /* Public | MethodRevisioned */,
      20,    1,  374,    2, 0x86 /* Public | MethodRevisioned */,
      22,    1,  377,    2, 0x86 /* Public | MethodRevisioned */,
      25,    0,  380,    2, 0x06 /* Public */,
      26,    0,  381,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      27,    1,  382,    2, 0x08 /* Private */,
      29,    1,  385,    2, 0x08 /* Private */,
      32,    0,  388,    2, 0x08 /* Private */,
      33,    4,  389,    2, 0x08 /* Private */,
      38,    1,  398,    2, 0x08 /* Private */,
      41,    1,  401,    2, 0x08 /* Private */,
      42,    1,  404,    2, 0x08 /* Private */,
      43,    1,  407,    2, 0x08 /* Private */,
      44,    1,  410,    2, 0x08 /* Private */,
      45,    0,  413,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      13,    1,  414,    2, 0x02 /* Public */,
      13,    1,  417,    2, 0x02 /* Public */,
      48,    4,  420,    2, 0x02 /* Public */,
      48,    3,  429,    2, 0x22 /* Public | MethodCloned */,
      48,    2,  436,    2, 0x22 /* Public | MethodCloned */,
      48,    1,  441,    2, 0x22 /* Public | MethodCloned */,
      53,    1,  444,    2, 0x02 /* Public */,
      54,    0,  447,    2, 0x02 /* Public */,
      55,    2,  448,    2, 0x02 /* Public */,
      55,    1,  453,    2, 0x22 /* Public | MethodCloned */,
      56,    2,  456,    2, 0x02 /* Public */,
      56,    1,  461,    2, 0x22 /* Public | MethodCloned */,
      51,    1,  464,    2, 0x02 /* Public */,
      51,    0,  467,    2, 0x22 /* Public | MethodCloned */,
      52,    1,  468,    2, 0x02 /* Public */,
      52,    0,  471,    2, 0x22 /* Public | MethodCloned */,
      57,    1,  472,    2, 0x02 /* Public */,
      59,    0,  475,    2, 0x82 /* Public | MethodRevisioned */,
      59,    1,  476,    2, 0x82 /* Public | MethodRevisioned */,
      61,    0,  479,    2, 0x82 /* Public | MethodRevisioned */,
      62,    0,  480,    2, 0x82 /* Public | MethodRevisioned */,
      63,    0,  481,    2, 0x82 /* Public | MethodRevisioned */,
      64,    1,  482,    2, 0x02 /* Public */,
      66,    1,  485,    2, 0x02 /* Public */,
      67,    1,  488,    2, 0x02 /* Public */,
      68,    1,  491,    2, 0x02 /* Public */,
      69,    2,  494,    2, 0x82 /* Public | MethodRevisioned */,
      69,    1,  499,    2, 0xa2 /* Public | MethodCloned | MethodRevisioned */,
      71,    2,  502,    2, 0x82 /* Public | MethodRevisioned */,
      71,    1,  507,    2, 0xa2 /* Public | MethodCloned | MethodRevisioned */,

 // signals: revision
       0,
       0,
       0,
       0,
       2,
       0,
       0,
       0,
       3,
       3,
       4,
       4,
       5,
       5,
       0,
       0,

 // slots: revision
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

 // methods: revision
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       5,
       5,
       5,
       5,
       5,
       0,
       0,
       0,
       0,
       5,
       5,
       5,
       5,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QColor,    4,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRectF,   10,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QReal,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,   28,
    QMetaType::Void, 0x80000000 | 30,   31,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,   34,   35,   36,   37,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,

 // methods: parameters
    0x80000000 | 12, QMetaType::Int,   46,
    0x80000000 | 12, QMetaType::QString,   47,
    0x80000000 | 12, QMetaType::Int, QMetaType::QString, 0x80000000 | 39, 0x80000000 | 39,   49,   50,   51,   52,
    0x80000000 | 12, QMetaType::Int, QMetaType::QString, 0x80000000 | 39,   49,   50,   51,
    0x80000000 | 12, QMetaType::Int, QMetaType::QString,   49,   50,
    0x80000000 | 12, QMetaType::Int,   49,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 39, 0x80000000 | 12,   40,   13,
    QMetaType::Void, 0x80000000 | 39,   40,
    QMetaType::Void, 0x80000000 | 39, 0x80000000 | 12,   40,   13,
    QMetaType::Void, 0x80000000 | 39,   40,
    0x80000000 | 39, 0x80000000 | 12,   13,
    0x80000000 | 39,
    0x80000000 | 39, 0x80000000 | 12,   13,
    0x80000000 | 39,
    QMetaType::Void, QMetaType::QReal,   58,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QRectF,   60,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QReal,   65,
    QMetaType::Void, QMetaType::QReal,   65,
    QMetaType::Void, QMetaType::QReal,   65,
    QMetaType::Void, QMetaType::QReal,   65,
    QMetaType::QPointF, QMetaType::QPointF, 0x80000000 | 12,   70,   13,
    QMetaType::QPointF, QMetaType::QPointF,   70,
    QMetaType::QPointF, QMetaType::QPointF, 0x80000000 | 12,   72,   13,
    QMetaType::QPointF, QMetaType::QPointF,   72,

 // properties: name, type, flags
      73, 0x80000000 | 74, 0x0009510b,
      75, 0x80000000 | 76, 0x0009510b,
      77, QMetaType::Int, 0x00c95103,
      78, 0x80000000 | 23, 0x00c9510b,
      79, QMetaType::QString, 0x00095103,
      80, QMetaType::QFont, 0x00095103,
      81, QMetaType::QColor, 0x00495103,
      82, 0x80000000 | 83, 0x00095409,
      84, QMetaType::Int, 0x00095001,
      85, QMetaType::QColor, 0x00495103,
      86, QMetaType::Bool, 0x00495103,
      87, QMetaType::QReal, 0x00c95103,
      88, 0x80000000 | 89, 0x00c95009,
      10, QMetaType::QRectF, 0x00c95103,
      90, QMetaType::QColor, 0x00c95103,
      91, 0x80000000 | 92, 0x00895009,
      93, QMetaType::Bool, 0x00c95103,
      94, QMetaType::QLocale, 0x00c95103,

 // properties: notify_signal_id
       0,
       0,
      12,
      13,
       0,
       0,
       1,
       0,
       0,
       2,
       3,
       9,
       4,
       5,
       8,
       0,
      10,
      11,

 // properties: revision
       0,
       0,
       5,
       5,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       3,
       2,
       1,
       3,
       2,
       4,
       4,

 // enums: name, alias, flags, count, data
      74,   74, 0x0,    8,  615,
      76,   76, 0x0,    4,  631,
     107,  107, 0x0,   13,  639,

 // enum data: key, value
      95, uint(QtCharts::DeclarativeChart::ChartThemeLight),
      96, uint(QtCharts::DeclarativeChart::ChartThemeBlueCerulean),
      97, uint(QtCharts::DeclarativeChart::ChartThemeDark),
      98, uint(QtCharts::DeclarativeChart::ChartThemeBrownSand),
      99, uint(QtCharts::DeclarativeChart::ChartThemeBlueNcs),
     100, uint(QtCharts::DeclarativeChart::ChartThemeHighContrast),
     101, uint(QtCharts::DeclarativeChart::ChartThemeBlueIcy),
     102, uint(QtCharts::DeclarativeChart::ChartThemeQt),
     103, uint(QtCharts::DeclarativeChart::NoAnimation),
     104, uint(QtCharts::DeclarativeChart::GridAxisAnimations),
     105, uint(QtCharts::DeclarativeChart::SeriesAnimations),
     106, uint(QtCharts::DeclarativeChart::AllAnimations),
     108, uint(QtCharts::DeclarativeChart::SeriesTypeLine),
     109, uint(QtCharts::DeclarativeChart::SeriesTypeArea),
     110, uint(QtCharts::DeclarativeChart::SeriesTypeBar),
     111, uint(QtCharts::DeclarativeChart::SeriesTypeStackedBar),
     112, uint(QtCharts::DeclarativeChart::SeriesTypePercentBar),
     113, uint(QtCharts::DeclarativeChart::SeriesTypePie),
     114, uint(QtCharts::DeclarativeChart::SeriesTypeScatter),
     115, uint(QtCharts::DeclarativeChart::SeriesTypeSpline),
     116, uint(QtCharts::DeclarativeChart::SeriesTypeHorizontalBar),
     117, uint(QtCharts::DeclarativeChart::SeriesTypeHorizontalStackedBar),
     118, uint(QtCharts::DeclarativeChart::SeriesTypeHorizontalPercentBar),
     119, uint(QtCharts::DeclarativeChart::SeriesTypeBoxPlot),
     120, uint(QtCharts::DeclarativeChart::SeriesTypeCandlestick),

       0        // eod
};

void QtCharts::DeclarativeChart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DeclarativeChart *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->axisLabelsChanged(); break;
        case 1: _t->titleColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 2: _t->backgroundColorChanged(); break;
        case 3: _t->dropShadowEnabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->marginsChanged(); break;
        case 5: _t->plotAreaChanged((*reinterpret_cast< QRectF(*)>(_a[1]))); break;
        case 6: _t->seriesAdded((*reinterpret_cast< QAbstractSeries*(*)>(_a[1]))); break;
        case 7: _t->seriesRemoved((*reinterpret_cast< QAbstractSeries*(*)>(_a[1]))); break;
        case 8: _t->plotAreaColorChanged(); break;
        case 9: _t->backgroundRoundnessChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 10: _t->localizeNumbersChanged(); break;
        case 11: _t->localeChanged(); break;
        case 12: _t->animationDurationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->animationEasingCurveChanged((*reinterpret_cast< QEasingCurve(*)>(_a[1]))); break;
        case 14: _t->needRender(); break;
        case 15: _t->pendingRenderNodeMouseEventResponses(); break;
        case 16: _t->handleAntialiasingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->sceneChanged((*reinterpret_cast< QList<QRectF>(*)>(_a[1]))); break;
        case 18: _t->renderScene(); break;
        case 19: _t->changeMargins((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 20: _t->handleAxisXSet((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 21: _t->handleAxisYSet((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 22: _t->handleAxisXTopSet((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 23: _t->handleAxisYRightSet((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 24: _t->handleSeriesAdded((*reinterpret_cast< QAbstractSeries*(*)>(_a[1]))); break;
        case 25: _t->handlePendingRenderNodeMouseEventResponses(); break;
        case 26: { QAbstractSeries* _r = _t->series((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 27: { QAbstractSeries* _r = _t->series((*reinterpret_cast< QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 28: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QAbstractAxis*(*)>(_a[3])),(*reinterpret_cast< QAbstractAxis*(*)>(_a[4])));
            if (_a[0]) *reinterpret_cast< QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 29: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QAbstractAxis*(*)>(_a[3])));
            if (_a[0]) *reinterpret_cast< QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 30: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 31: { QAbstractSeries* _r = _t->createSeries((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAbstractSeries**>(_a[0]) = std::move(_r); }  break;
        case 32: _t->removeSeries((*reinterpret_cast< QAbstractSeries*(*)>(_a[1]))); break;
        case 33: _t->removeAllSeries(); break;
        case 34: _t->setAxisX((*reinterpret_cast< QAbstractAxis*(*)>(_a[1])),(*reinterpret_cast< QAbstractSeries*(*)>(_a[2]))); break;
        case 35: _t->setAxisX((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 36: _t->setAxisY((*reinterpret_cast< QAbstractAxis*(*)>(_a[1])),(*reinterpret_cast< QAbstractSeries*(*)>(_a[2]))); break;
        case 37: _t->setAxisY((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 38: { QAbstractAxis* _r = _t->axisX((*reinterpret_cast< QAbstractSeries*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 39: { QAbstractAxis* _r = _t->axisX();
            if (_a[0]) *reinterpret_cast< QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 40: { QAbstractAxis* _r = _t->axisY((*reinterpret_cast< QAbstractSeries*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 41: { QAbstractAxis* _r = _t->axisY();
            if (_a[0]) *reinterpret_cast< QAbstractAxis**>(_a[0]) = std::move(_r); }  break;
        case 42: _t->zoom((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 43: _t->zoomIn(); break;
        case 44: _t->zoomIn((*reinterpret_cast< const QRectF(*)>(_a[1]))); break;
        case 45: _t->zoomOut(); break;
        case 46: _t->zoomReset(); break;
        case 47: { bool _r = _t->isZoomed();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->scrollLeft((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 49: _t->scrollRight((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 50: _t->scrollUp((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 51: _t->scrollDown((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 52: { QPointF _r = _t->mapToValue((*reinterpret_cast< const QPointF(*)>(_a[1])),(*reinterpret_cast< QAbstractSeries*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 53: { QPointF _r = _t->mapToValue((*reinterpret_cast< const QPointF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 54: { QPointF _r = _t->mapToPosition((*reinterpret_cast< const QPointF(*)>(_a[1])),(*reinterpret_cast< QAbstractSeries*(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        case 55: { QPointF _r = _t->mapToPosition((*reinterpret_cast< const QPointF(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QRectF> >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 3:
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 38:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        case 54:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractSeries* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::axisLabelsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::titleColorChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::backgroundColorChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::dropShadowEnabledChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::marginsChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(QRectF );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::plotAreaChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(QAbstractSeries * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::seriesAdded)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(QAbstractSeries * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::seriesRemoved)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::plotAreaColorChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::backgroundRoundnessChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::localizeNumbersChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::localeChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::animationDurationChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)(QEasingCurve );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::animationEasingCurveChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::needRender)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (DeclarativeChart::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeChart::pendingRenderNodeMouseEventResponses)) {
                *result = 15;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtCharts::QLegend* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DeclarativeChart *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< Theme*>(_v) = _t->theme(); break;
        case 1: *reinterpret_cast< Animation*>(_v) = _t->animationOptions(); break;
        case 2: *reinterpret_cast< int*>(_v) = _t->animationDuration(); break;
        case 3: *reinterpret_cast< QEasingCurve*>(_v) = _t->animationEasingCurve(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 5: *reinterpret_cast< QFont*>(_v) = _t->titleFont(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->titleColor(); break;
        case 7: *reinterpret_cast< QtCharts::QLegend**>(_v) = _t->legend(); break;
        case 8: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 9: *reinterpret_cast< QColor*>(_v) = _t->backgroundColor(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->dropShadowEnabled(); break;
        case 11: *reinterpret_cast< qreal*>(_v) = _t->backgroundRoundness(); break;
        case 12: *reinterpret_cast< QtCharts::DeclarativeMargins**>(_v) = _t->margins(); break;
        case 13: *reinterpret_cast< QRectF*>(_v) = _t->plotArea(); break;
        case 14: *reinterpret_cast< QColor*>(_v) = _t->plotAreaColor(); break;
        case 15: *reinterpret_cast< QQmlListProperty<QAbstractAxis>*>(_v) = _t->axes(); break;
        case 16: *reinterpret_cast< bool*>(_v) = _t->localizeNumbers(); break;
        case 17: *reinterpret_cast< QLocale*>(_v) = _t->locale(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DeclarativeChart *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTheme(*reinterpret_cast< Theme*>(_v)); break;
        case 1: _t->setAnimationOptions(*reinterpret_cast< Animation*>(_v)); break;
        case 2: _t->setAnimationDuration(*reinterpret_cast< int*>(_v)); break;
        case 3: _t->setAnimationEasingCurve(*reinterpret_cast< QEasingCurve*>(_v)); break;
        case 4: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setTitleFont(*reinterpret_cast< QFont*>(_v)); break;
        case 6: _t->setTitleColor(*reinterpret_cast< QColor*>(_v)); break;
        case 9: _t->setBackgroundColor(*reinterpret_cast< QColor*>(_v)); break;
        case 10: _t->setDropShadowEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setBackgroundRoundness(*reinterpret_cast< qreal*>(_v)); break;
        case 13: _t->setPlotArea(*reinterpret_cast< QRectF*>(_v)); break;
        case 14: _t->setPlotAreaColor(*reinterpret_cast< QColor*>(_v)); break;
        case 16: _t->setLocalizeNumbers(*reinterpret_cast< bool*>(_v)); break;
        case 17: _t->setLocale(*reinterpret_cast< QLocale*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::DeclarativeChart::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__DeclarativeChart.data,
    qt_meta_data_QtCharts__DeclarativeChart,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::DeclarativeChart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::DeclarativeChart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__DeclarativeChart.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QtCharts::DeclarativeChart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 18;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::DeclarativeChart::axisLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QtCharts::DeclarativeChart::titleColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::DeclarativeChart::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QtCharts::DeclarativeChart::dropShadowEnabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::DeclarativeChart::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QtCharts::DeclarativeChart::plotAreaChanged(QRectF _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QtCharts::DeclarativeChart::seriesAdded(QAbstractSeries * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QtCharts::DeclarativeChart::seriesRemoved(QAbstractSeries * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QtCharts::DeclarativeChart::plotAreaColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QtCharts::DeclarativeChart::backgroundRoundnessChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void QtCharts::DeclarativeChart::localizeNumbersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QtCharts::DeclarativeChart::localeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QtCharts::DeclarativeChart::animationDurationChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void QtCharts::DeclarativeChart::animationEasingCurveChanged(QEasingCurve _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void QtCharts::DeclarativeChart::needRender()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QtCharts::DeclarativeChart::pendingRenderNodeMouseEventResponses()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
