/****************************************************************************
** Meta object code from reading C++ file 'declarativesplineseries_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/chartsqml2/declarativesplineseries_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativesplineseries_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__DeclarativeSplineSeries_t {
    QByteArrayData data[49];
    char stringdata0[571];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__DeclarativeSplineSeries_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__DeclarativeSplineSeries_t qt_meta_stringdata_QtCharts__DeclarativeSplineSeries = {
    {
QT_MOC_LITERAL(0, 0, 33), // "QtCharts::DeclarativeSplineSe..."
QT_MOC_LITERAL(1, 34, 15), // "DefaultProperty"
QT_MOC_LITERAL(2, 50, 19), // "declarativeChildren"
QT_MOC_LITERAL(3, 70, 12), // "countChanged"
QT_MOC_LITERAL(4, 83, 0), // ""
QT_MOC_LITERAL(5, 84, 5), // "count"
QT_MOC_LITERAL(6, 90, 12), // "axisXChanged"
QT_MOC_LITERAL(7, 103, 14), // "QAbstractAxis*"
QT_MOC_LITERAL(8, 118, 4), // "axis"
QT_MOC_LITERAL(9, 123, 12), // "axisYChanged"
QT_MOC_LITERAL(10, 136, 15), // "axisXTopChanged"
QT_MOC_LITERAL(11, 152, 17), // "axisYRightChanged"
QT_MOC_LITERAL(12, 170, 18), // "axisAngularChanged"
QT_MOC_LITERAL(13, 189, 17), // "axisRadialChanged"
QT_MOC_LITERAL(14, 207, 12), // "widthChanged"
QT_MOC_LITERAL(15, 220, 5), // "width"
QT_MOC_LITERAL(16, 226, 12), // "styleChanged"
QT_MOC_LITERAL(17, 239, 12), // "Qt::PenStyle"
QT_MOC_LITERAL(18, 252, 5), // "style"
QT_MOC_LITERAL(19, 258, 15), // "capStyleChanged"
QT_MOC_LITERAL(20, 274, 15), // "Qt::PenCapStyle"
QT_MOC_LITERAL(21, 290, 8), // "capStyle"
QT_MOC_LITERAL(22, 299, 25), // "appendDeclarativeChildren"
QT_MOC_LITERAL(23, 325, 26), // "QQmlListProperty<QObject>*"
QT_MOC_LITERAL(24, 352, 4), // "list"
QT_MOC_LITERAL(25, 357, 7), // "element"
QT_MOC_LITERAL(26, 365, 18), // "handleCountChanged"
QT_MOC_LITERAL(27, 384, 5), // "index"
QT_MOC_LITERAL(28, 390, 6), // "append"
QT_MOC_LITERAL(29, 397, 1), // "x"
QT_MOC_LITERAL(30, 399, 1), // "y"
QT_MOC_LITERAL(31, 401, 7), // "replace"
QT_MOC_LITERAL(32, 409, 4), // "oldX"
QT_MOC_LITERAL(33, 414, 4), // "oldY"
QT_MOC_LITERAL(34, 419, 4), // "newX"
QT_MOC_LITERAL(35, 424, 4), // "newY"
QT_MOC_LITERAL(36, 429, 6), // "remove"
QT_MOC_LITERAL(37, 436, 12), // "removePoints"
QT_MOC_LITERAL(38, 449, 6), // "insert"
QT_MOC_LITERAL(39, 456, 5), // "clear"
QT_MOC_LITERAL(40, 462, 2), // "at"
QT_MOC_LITERAL(41, 465, 5), // "axisX"
QT_MOC_LITERAL(42, 471, 24), // "QtCharts::QAbstractAxis*"
QT_MOC_LITERAL(43, 496, 5), // "axisY"
QT_MOC_LITERAL(44, 502, 8), // "axisXTop"
QT_MOC_LITERAL(45, 511, 10), // "axisYRight"
QT_MOC_LITERAL(46, 522, 11), // "axisAngular"
QT_MOC_LITERAL(47, 534, 10), // "axisRadial"
QT_MOC_LITERAL(48, 545, 25) // "QQmlListProperty<QObject>"

    },
    "QtCharts::DeclarativeSplineSeries\0"
    "DefaultProperty\0declarativeChildren\0"
    "countChanged\0\0count\0axisXChanged\0"
    "QAbstractAxis*\0axis\0axisYChanged\0"
    "axisXTopChanged\0axisYRightChanged\0"
    "axisAngularChanged\0axisRadialChanged\0"
    "widthChanged\0width\0styleChanged\0"
    "Qt::PenStyle\0style\0capStyleChanged\0"
    "Qt::PenCapStyle\0capStyle\0"
    "appendDeclarativeChildren\0"
    "QQmlListProperty<QObject>*\0list\0element\0"
    "handleCountChanged\0index\0append\0x\0y\0"
    "replace\0oldX\0oldY\0newX\0newY\0remove\0"
    "removePoints\0insert\0clear\0at\0axisX\0"
    "QtCharts::QAbstractAxis*\0axisY\0axisXTop\0"
    "axisYRight\0axisAngular\0axisRadial\0"
    "QQmlListProperty<QObject>"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__DeclarativeSplineSeries[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      21,   16, // methods
      11,  225, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,  142,    4, 0x06 /* Public */,
       6,    1,  145,    4, 0x86 /* Public | MethodRevisioned */,
       9,    1,  148,    4, 0x86 /* Public | MethodRevisioned */,
      10,    1,  151,    4, 0x86 /* Public | MethodRevisioned */,
      11,    1,  154,    4, 0x86 /* Public | MethodRevisioned */,
      12,    1,  157,    4, 0x86 /* Public | MethodRevisioned */,
      13,    1,  160,    4, 0x86 /* Public | MethodRevisioned */,
      14,    1,  163,    4, 0x86 /* Public | MethodRevisioned */,
      16,    1,  166,    4, 0x86 /* Public | MethodRevisioned */,
      19,    1,  169,    4, 0x86 /* Public | MethodRevisioned */,

 // slots: name, argc, parameters, tag, flags
      22,    2,  172,    4, 0x0a /* Public */,
      26,    1,  177,    4, 0x0a /* Public */,

 // methods: name, argc, parameters, tag, flags
      28,    2,  180,    4, 0x02 /* Public */,
      31,    4,  185,    4, 0x02 /* Public */,
      31,    3,  194,    4, 0x82 /* Public | MethodRevisioned */,
      36,    2,  201,    4, 0x02 /* Public */,
      36,    1,  206,    4, 0x82 /* Public | MethodRevisioned */,
      37,    2,  209,    4, 0x82 /* Public | MethodRevisioned */,
      38,    3,  214,    4, 0x02 /* Public */,
      39,    0,  221,    4, 0x02 /* Public */,
      40,    1,  222,    4, 0x02 /* Public */,

 // signals: revision
       0,
       1,
       1,
       2,
       2,
       3,
       3,
       1,
       1,
       1,

 // slots: revision
       0,
       0,

 // methods: revision
       0,
       0,
       3,
       0,
       3,
       4,
       0,
       0,
       0,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, QMetaType::QReal,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void, 0x80000000 | 20,   21,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 23, QMetaType::QObjectStar,   24,   25,
    QMetaType::Void, QMetaType::Int,   27,

 // methods: parameters
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   29,   30,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal, QMetaType::QReal,   32,   33,   34,   35,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal, QMetaType::QReal,   27,   34,   35,
    QMetaType::Void, QMetaType::QReal, QMetaType::QReal,   29,   30,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   27,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::QReal, QMetaType::QReal,   27,   29,   30,
    QMetaType::Void,
    QMetaType::QPointF, QMetaType::Int,   27,

 // properties: name, type, flags
       5, QMetaType::Int, 0x00495001,
      41, 0x80000000 | 42, 0x00c9510b,
      43, 0x80000000 | 42, 0x00c9510b,
      44, 0x80000000 | 42, 0x00c9510b,
      45, 0x80000000 | 42, 0x00c9510b,
      46, 0x80000000 | 42, 0x00c9510b,
      47, 0x80000000 | 42, 0x00c9510b,
      15, QMetaType::QReal, 0x00c95103,
      18, 0x80000000 | 17, 0x00c9510b,
      21, 0x80000000 | 20, 0x00c9510b,
       2, 0x80000000 | 48, 0x00095009,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
       0,

 // properties: revision
       0,
       1,
       1,
       2,
       2,
       3,
       3,
       1,
       1,
       1,
       0,

       0        // eod
};

void QtCharts::DeclarativeSplineSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DeclarativeSplineSeries *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->countChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->axisXChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 2: _t->axisYChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 3: _t->axisXTopChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 4: _t->axisYRightChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 5: _t->axisAngularChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 6: _t->axisRadialChanged((*reinterpret_cast< QAbstractAxis*(*)>(_a[1]))); break;
        case 7: _t->widthChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 8: _t->styleChanged((*reinterpret_cast< Qt::PenStyle(*)>(_a[1]))); break;
        case 9: _t->capStyleChanged((*reinterpret_cast< Qt::PenCapStyle(*)>(_a[1]))); break;
        case 10: _t->appendDeclarativeChildren((*reinterpret_cast< QQmlListProperty<QObject>*(*)>(_a[1])),(*reinterpret_cast< QObject*(*)>(_a[2]))); break;
        case 11: _t->handleCountChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->append((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 13: _t->replace((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3])),(*reinterpret_cast< qreal(*)>(_a[4]))); break;
        case 14: _t->replace((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 15: _t->remove((*reinterpret_cast< qreal(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2]))); break;
        case 16: _t->remove((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->removePoints((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 18: _t->insert((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< qreal(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 19: _t->clear(); break;
        case 20: { QPointF _r = _t->at((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QPointF*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractAxis* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DeclarativeSplineSeries::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::countChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::axisXChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::axisYChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::axisXTopChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::axisYRightChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::axisAngularChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(QAbstractAxis * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::axisRadialChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::widthChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(Qt::PenStyle );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::styleChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DeclarativeSplineSeries::*)(Qt::PenCapStyle );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DeclarativeSplineSeries::capStyleChanged)) {
                *result = 9;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
        case 5:
        case 4:
        case 3:
        case 2:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QtCharts::QAbstractAxis* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DeclarativeSplineSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisX(); break;
        case 2: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisY(); break;
        case 3: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisXTop(); break;
        case 4: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisYRight(); break;
        case 5: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisAngular(); break;
        case 6: *reinterpret_cast< QtCharts::QAbstractAxis**>(_v) = _t->axisRadial(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->width(); break;
        case 8: *reinterpret_cast< Qt::PenStyle*>(_v) = _t->style(); break;
        case 9: *reinterpret_cast< Qt::PenCapStyle*>(_v) = _t->capStyle(); break;
        case 10: *reinterpret_cast< QQmlListProperty<QObject>*>(_v) = _t->declarativeChildren(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DeclarativeSplineSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setAxisX(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 2: _t->setAxisY(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 3: _t->setAxisXTop(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 4: _t->setAxisYRight(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 5: _t->setAxisAngular(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 6: _t->setAxisRadial(*reinterpret_cast< QtCharts::QAbstractAxis**>(_v)); break;
        case 7: _t->setWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 8: _t->setStyle(*reinterpret_cast< Qt::PenStyle*>(_v)); break;
        case 9: _t->setCapStyle(*reinterpret_cast< Qt::PenCapStyle*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::DeclarativeSplineSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QSplineSeries::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__DeclarativeSplineSeries.data,
    qt_meta_data_QtCharts__DeclarativeSplineSeries,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::DeclarativeSplineSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::DeclarativeSplineSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__DeclarativeSplineSeries.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DeclarativeXySeries"))
        return static_cast< DeclarativeXySeries*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QSplineSeries::qt_metacast(_clname);
}

int QtCharts::DeclarativeSplineSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplineSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::DeclarativeSplineSeries::countChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::DeclarativeSplineSeries::axisXChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::DeclarativeSplineSeries::axisYChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::DeclarativeSplineSeries::axisXTopChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::DeclarativeSplineSeries::axisYRightChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::DeclarativeSplineSeries::axisAngularChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QtCharts::DeclarativeSplineSeries::axisRadialChanged(QAbstractAxis * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QtCharts::DeclarativeSplineSeries::widthChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QtCharts::DeclarativeSplineSeries::styleChanged(Qt::PenStyle _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QtCharts::DeclarativeSplineSeries::capStyleChanged(Qt::PenCapStyle _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
