/****************************************************************************
** Meta object code from reading C++ file 'qpieslice.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/piechart/qpieslice.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qpieslice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QPieSlice_t {
    QByteArrayData data[45];
    char stringdata0[585];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QPieSlice_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QPieSlice_t qt_meta_stringdata_QtCharts__QPieSlice = {
    {
QT_MOC_LITERAL(0, 0, 19), // "QtCharts::QPieSlice"
QT_MOC_LITERAL(1, 20, 7), // "clicked"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 7), // "hovered"
QT_MOC_LITERAL(4, 37, 5), // "state"
QT_MOC_LITERAL(5, 43, 7), // "pressed"
QT_MOC_LITERAL(6, 51, 8), // "released"
QT_MOC_LITERAL(7, 60, 13), // "doubleClicked"
QT_MOC_LITERAL(8, 74, 12), // "labelChanged"
QT_MOC_LITERAL(9, 87, 12), // "valueChanged"
QT_MOC_LITERAL(10, 100, 19), // "labelVisibleChanged"
QT_MOC_LITERAL(11, 120, 10), // "penChanged"
QT_MOC_LITERAL(12, 131, 12), // "brushChanged"
QT_MOC_LITERAL(13, 144, 17), // "labelBrushChanged"
QT_MOC_LITERAL(14, 162, 16), // "labelFontChanged"
QT_MOC_LITERAL(15, 179, 17), // "percentageChanged"
QT_MOC_LITERAL(16, 197, 17), // "startAngleChanged"
QT_MOC_LITERAL(17, 215, 16), // "angleSpanChanged"
QT_MOC_LITERAL(18, 232, 12), // "colorChanged"
QT_MOC_LITERAL(19, 245, 18), // "borderColorChanged"
QT_MOC_LITERAL(20, 264, 18), // "borderWidthChanged"
QT_MOC_LITERAL(21, 283, 17), // "labelColorChanged"
QT_MOC_LITERAL(22, 301, 5), // "label"
QT_MOC_LITERAL(23, 307, 5), // "value"
QT_MOC_LITERAL(24, 313, 12), // "labelVisible"
QT_MOC_LITERAL(25, 326, 13), // "labelPosition"
QT_MOC_LITERAL(26, 340, 13), // "LabelPosition"
QT_MOC_LITERAL(27, 354, 8), // "exploded"
QT_MOC_LITERAL(28, 363, 3), // "pen"
QT_MOC_LITERAL(29, 367, 11), // "borderColor"
QT_MOC_LITERAL(30, 379, 11), // "borderWidth"
QT_MOC_LITERAL(31, 391, 5), // "brush"
QT_MOC_LITERAL(32, 397, 5), // "color"
QT_MOC_LITERAL(33, 403, 10), // "labelBrush"
QT_MOC_LITERAL(34, 414, 10), // "labelColor"
QT_MOC_LITERAL(35, 425, 9), // "labelFont"
QT_MOC_LITERAL(36, 435, 20), // "labelArmLengthFactor"
QT_MOC_LITERAL(37, 456, 21), // "explodeDistanceFactor"
QT_MOC_LITERAL(38, 478, 10), // "percentage"
QT_MOC_LITERAL(39, 489, 10), // "startAngle"
QT_MOC_LITERAL(40, 500, 9), // "angleSpan"
QT_MOC_LITERAL(41, 510, 12), // "LabelOutside"
QT_MOC_LITERAL(42, 523, 21), // "LabelInsideHorizontal"
QT_MOC_LITERAL(43, 545, 21), // "LabelInsideTangential"
QT_MOC_LITERAL(44, 567, 17) // "LabelInsideNormal"

    },
    "QtCharts::QPieSlice\0clicked\0\0hovered\0"
    "state\0pressed\0released\0doubleClicked\0"
    "labelChanged\0valueChanged\0labelVisibleChanged\0"
    "penChanged\0brushChanged\0labelBrushChanged\0"
    "labelFontChanged\0percentageChanged\0"
    "startAngleChanged\0angleSpanChanged\0"
    "colorChanged\0borderColorChanged\0"
    "borderWidthChanged\0labelColorChanged\0"
    "label\0value\0labelVisible\0labelPosition\0"
    "LabelPosition\0exploded\0pen\0borderColor\0"
    "borderWidth\0brush\0color\0labelBrush\0"
    "labelColor\0labelFont\0labelArmLengthFactor\0"
    "explodeDistanceFactor\0percentage\0"
    "startAngle\0angleSpan\0LabelOutside\0"
    "LabelInsideHorizontal\0LabelInsideTangential\0"
    "LabelInsideNormal"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QPieSlice[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
      18,  130, // properties
       1,  202, // enums/sets
       0,    0, // constructors
       0,       // flags
      19,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  109,    2, 0x06 /* Public */,
       3,    1,  110,    2, 0x06 /* Public */,
       5,    0,  113,    2, 0x06 /* Public */,
       6,    0,  114,    2, 0x06 /* Public */,
       7,    0,  115,    2, 0x06 /* Public */,
       8,    0,  116,    2, 0x06 /* Public */,
       9,    0,  117,    2, 0x06 /* Public */,
      10,    0,  118,    2, 0x06 /* Public */,
      11,    0,  119,    2, 0x06 /* Public */,
      12,    0,  120,    2, 0x06 /* Public */,
      13,    0,  121,    2, 0x06 /* Public */,
      14,    0,  122,    2, 0x06 /* Public */,
      15,    0,  123,    2, 0x06 /* Public */,
      16,    0,  124,    2, 0x06 /* Public */,
      17,    0,  125,    2, 0x06 /* Public */,
      18,    0,  126,    2, 0x06 /* Public */,
      19,    0,  127,    2, 0x06 /* Public */,
      20,    0,  128,    2, 0x06 /* Public */,
      21,    0,  129,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      22, QMetaType::QString, 0x00495103,
      23, QMetaType::QReal, 0x00495103,
      24, QMetaType::Bool, 0x00495103,
      25, 0x80000000 | 26, 0x0009510b,
      27, QMetaType::Bool, 0x00095103,
      28, QMetaType::QPen, 0x00495103,
      29, QMetaType::QColor, 0x00495103,
      30, QMetaType::Int, 0x00495103,
      31, QMetaType::QBrush, 0x00495103,
      32, QMetaType::QColor, 0x00495103,
      33, QMetaType::QBrush, 0x00495103,
      34, QMetaType::QColor, 0x00495103,
      35, QMetaType::QFont, 0x00495103,
      36, QMetaType::QReal, 0x00095103,
      37, QMetaType::QReal, 0x00095103,
      38, QMetaType::QReal, 0x00495001,
      39, QMetaType::QReal, 0x00495001,
      40, QMetaType::QReal, 0x00495001,

 // properties: notify_signal_id
       5,
       6,
       7,
       0,
       0,
       8,
      16,
      17,
       9,
      15,
      10,
      18,
      11,
       0,
       0,
      12,
      13,
      14,

 // enums: name, alias, flags, count, data
      26,   26, 0x0,    4,  207,

 // enum data: key, value
      41, uint(QtCharts::QPieSlice::LabelOutside),
      42, uint(QtCharts::QPieSlice::LabelInsideHorizontal),
      43, uint(QtCharts::QPieSlice::LabelInsideTangential),
      44, uint(QtCharts::QPieSlice::LabelInsideNormal),

       0        // eod
};

void QtCharts::QPieSlice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QPieSlice *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->hovered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->pressed(); break;
        case 3: _t->released(); break;
        case 4: _t->doubleClicked(); break;
        case 5: _t->labelChanged(); break;
        case 6: _t->valueChanged(); break;
        case 7: _t->labelVisibleChanged(); break;
        case 8: _t->penChanged(); break;
        case 9: _t->brushChanged(); break;
        case 10: _t->labelBrushChanged(); break;
        case 11: _t->labelFontChanged(); break;
        case 12: _t->percentageChanged(); break;
        case 13: _t->startAngleChanged(); break;
        case 14: _t->angleSpanChanged(); break;
        case 15: _t->colorChanged(); break;
        case 16: _t->borderColorChanged(); break;
        case 17: _t->borderWidthChanged(); break;
        case 18: _t->labelColorChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::hovered)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::pressed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::released)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::doubleClicked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::labelChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::valueChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::labelVisibleChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::penChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::brushChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::labelBrushChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::labelFontChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::percentageChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::startAngleChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::angleSpanChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::colorChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::borderColorChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::borderWidthChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (QPieSlice::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QPieSlice::labelColorChanged)) {
                *result = 18;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QPieSlice *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->value(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isLabelVisible(); break;
        case 3: *reinterpret_cast< LabelPosition*>(_v) = _t->labelPosition(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isExploded(); break;
        case 5: *reinterpret_cast< QPen*>(_v) = _t->pen(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->borderColor(); break;
        case 7: *reinterpret_cast< int*>(_v) = _t->borderWidth(); break;
        case 8: *reinterpret_cast< QBrush*>(_v) = _t->brush(); break;
        case 9: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 10: *reinterpret_cast< QBrush*>(_v) = _t->labelBrush(); break;
        case 11: *reinterpret_cast< QColor*>(_v) = _t->labelColor(); break;
        case 12: *reinterpret_cast< QFont*>(_v) = _t->labelFont(); break;
        case 13: *reinterpret_cast< qreal*>(_v) = _t->labelArmLengthFactor(); break;
        case 14: *reinterpret_cast< qreal*>(_v) = _t->explodeDistanceFactor(); break;
        case 15: *reinterpret_cast< qreal*>(_v) = _t->percentage(); break;
        case 16: *reinterpret_cast< qreal*>(_v) = _t->startAngle(); break;
        case 17: *reinterpret_cast< qreal*>(_v) = _t->angleSpan(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QPieSlice *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setValue(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setLabelVisible(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setLabelPosition(*reinterpret_cast< LabelPosition*>(_v)); break;
        case 4: _t->setExploded(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setPen(*reinterpret_cast< QPen*>(_v)); break;
        case 6: _t->setBorderColor(*reinterpret_cast< QColor*>(_v)); break;
        case 7: _t->setBorderWidth(*reinterpret_cast< int*>(_v)); break;
        case 8: _t->setBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 9: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 10: _t->setLabelBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 11: _t->setLabelColor(*reinterpret_cast< QColor*>(_v)); break;
        case 12: _t->setLabelFont(*reinterpret_cast< QFont*>(_v)); break;
        case 13: _t->setLabelArmLengthFactor(*reinterpret_cast< qreal*>(_v)); break;
        case 14: _t->setExplodeDistanceFactor(*reinterpret_cast< qreal*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QPieSlice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QPieSlice.data,
    qt_meta_data_QtCharts__QPieSlice,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QPieSlice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QPieSlice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QPieSlice.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QtCharts::QPieSlice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 18;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 18;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QPieSlice::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QtCharts::QPieSlice::hovered(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QPieSlice::pressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QtCharts::QPieSlice::released()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QtCharts::QPieSlice::doubleClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QtCharts::QPieSlice::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QtCharts::QPieSlice::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QtCharts::QPieSlice::labelVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QtCharts::QPieSlice::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QtCharts::QPieSlice::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QtCharts::QPieSlice::labelBrushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QtCharts::QPieSlice::labelFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QtCharts::QPieSlice::percentageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QtCharts::QPieSlice::startAngleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QtCharts::QPieSlice::angleSpanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QtCharts::QPieSlice::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QtCharts::QPieSlice::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QtCharts::QPieSlice::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QtCharts::QPieSlice::labelColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
