/****************************************************************************
** Meta object code from reading C++ file 'qlegendmarker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/legend/qlegendmarker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qlegendmarker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QLegendMarker_t {
    QByteArrayData data[27];
    char stringdata0[369];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QLegendMarker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QLegendMarker_t qt_meta_stringdata_QtCharts__QLegendMarker = {
    {
QT_MOC_LITERAL(0, 0, 23), // "QtCharts::QLegendMarker"
QT_MOC_LITERAL(1, 24, 7), // "clicked"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 7), // "hovered"
QT_MOC_LITERAL(4, 41, 6), // "status"
QT_MOC_LITERAL(5, 48, 12), // "labelChanged"
QT_MOC_LITERAL(6, 61, 17), // "labelBrushChanged"
QT_MOC_LITERAL(7, 79, 11), // "fontChanged"
QT_MOC_LITERAL(8, 91, 10), // "penChanged"
QT_MOC_LITERAL(9, 102, 12), // "brushChanged"
QT_MOC_LITERAL(10, 115, 14), // "visibleChanged"
QT_MOC_LITERAL(11, 130, 12), // "shapeChanged"
QT_MOC_LITERAL(12, 143, 5), // "label"
QT_MOC_LITERAL(13, 149, 10), // "labelBrush"
QT_MOC_LITERAL(14, 160, 4), // "font"
QT_MOC_LITERAL(15, 165, 3), // "pen"
QT_MOC_LITERAL(16, 169, 5), // "brush"
QT_MOC_LITERAL(17, 175, 7), // "visible"
QT_MOC_LITERAL(18, 183, 5), // "shape"
QT_MOC_LITERAL(19, 189, 30), // "QtCharts::QLegend::MarkerShape"
QT_MOC_LITERAL(20, 220, 16), // "LegendMarkerType"
QT_MOC_LITERAL(21, 237, 20), // "LegendMarkerTypeArea"
QT_MOC_LITERAL(22, 258, 19), // "LegendMarkerTypeBar"
QT_MOC_LITERAL(23, 278, 19), // "LegendMarkerTypePie"
QT_MOC_LITERAL(24, 298, 18), // "LegendMarkerTypeXY"
QT_MOC_LITERAL(25, 317, 23), // "LegendMarkerTypeBoxPlot"
QT_MOC_LITERAL(26, 341, 27) // "LegendMarkerTypeCandlestick"

    },
    "QtCharts::QLegendMarker\0clicked\0\0"
    "hovered\0status\0labelChanged\0"
    "labelBrushChanged\0fontChanged\0penChanged\0"
    "brushChanged\0visibleChanged\0shapeChanged\0"
    "label\0labelBrush\0font\0pen\0brush\0visible\0"
    "shape\0QtCharts::QLegend::MarkerShape\0"
    "LegendMarkerType\0LegendMarkerTypeArea\0"
    "LegendMarkerTypeBar\0LegendMarkerTypePie\0"
    "LegendMarkerTypeXY\0LegendMarkerTypeBoxPlot\0"
    "LegendMarkerTypeCandlestick"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QLegendMarker[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       7,   70, // properties
       1,   98, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,
       5,    0,   63,    2, 0x06 /* Public */,
       6,    0,   64,    2, 0x06 /* Public */,
       7,    0,   65,    2, 0x06 /* Public */,
       8,    0,   66,    2, 0x06 /* Public */,
       9,    0,   67,    2, 0x06 /* Public */,
      10,    0,   68,    2, 0x06 /* Public */,
      11,    0,   69,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      12, QMetaType::QString, 0x00495103,
      13, QMetaType::QBrush, 0x00495103,
      14, QMetaType::QFont, 0x00495103,
      15, QMetaType::QPen, 0x00495103,
      16, QMetaType::QBrush, 0x00495103,
      17, QMetaType::Bool, 0x00495103,
      18, 0x80000000 | 19, 0x0049510b,

 // properties: notify_signal_id
       2,
       3,
       4,
       5,
       6,
       7,
       8,

 // enums: name, alias, flags, count, data
      20,   20, 0x0,    6,  103,

 // enum data: key, value
      21, uint(QtCharts::QLegendMarker::LegendMarkerTypeArea),
      22, uint(QtCharts::QLegendMarker::LegendMarkerTypeBar),
      23, uint(QtCharts::QLegendMarker::LegendMarkerTypePie),
      24, uint(QtCharts::QLegendMarker::LegendMarkerTypeXY),
      25, uint(QtCharts::QLegendMarker::LegendMarkerTypeBoxPlot),
      26, uint(QtCharts::QLegendMarker::LegendMarkerTypeCandlestick),

       0        // eod
};

void QtCharts::QLegendMarker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QLegendMarker *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked(); break;
        case 1: _t->hovered((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->labelChanged(); break;
        case 3: _t->labelBrushChanged(); break;
        case 4: _t->fontChanged(); break;
        case 5: _t->penChanged(); break;
        case 6: _t->brushChanged(); break;
        case 7: _t->visibleChanged(); break;
        case 8: _t->shapeChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::hovered)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::labelChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::labelBrushChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::fontChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::penChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::brushChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::visibleChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QLegendMarker::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QLegendMarker::shapeChanged)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QLegendMarker *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast< QBrush*>(_v) = _t->labelBrush(); break;
        case 2: *reinterpret_cast< QFont*>(_v) = _t->font(); break;
        case 3: *reinterpret_cast< QPen*>(_v) = _t->pen(); break;
        case 4: *reinterpret_cast< QBrush*>(_v) = _t->brush(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->isVisible(); break;
        case 6: *reinterpret_cast< QtCharts::QLegend::MarkerShape*>(_v) = _t->shape(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QLegendMarker *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setLabelBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 2: _t->setFont(*reinterpret_cast< QFont*>(_v)); break;
        case 3: _t->setPen(*reinterpret_cast< QPen*>(_v)); break;
        case 4: _t->setBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 5: _t->setVisible(*reinterpret_cast< bool*>(_v)); break;
        case 6: _t->setShape(*reinterpret_cast< QtCharts::QLegend::MarkerShape*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

static const QMetaObject::SuperData qt_meta_extradata_QtCharts__QLegendMarker[] = {
    QMetaObject::SuperData::link<QtCharts::QLegend::staticMetaObject>(),
    nullptr
};

QT_INIT_METAOBJECT const QMetaObject QtCharts::QLegendMarker::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QLegendMarker.data,
    qt_meta_data_QtCharts__QLegendMarker,
    qt_static_metacall,
    qt_meta_extradata_QtCharts__QLegendMarker,
    nullptr
} };


const QMetaObject *QtCharts::QLegendMarker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QLegendMarker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QLegendMarker.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QtCharts::QLegendMarker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QLegendMarker::clicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QtCharts::QLegendMarker::hovered(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QLegendMarker::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QtCharts::QLegendMarker::labelBrushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QtCharts::QLegendMarker::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QtCharts::QLegendMarker::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QtCharts::QLegendMarker::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QtCharts::QLegendMarker::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QtCharts::QLegendMarker::shapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
