/****************************************************************************
** Meta object code from reading C++ file 'qchart.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/qchart.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qchart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QChart_t {
    QByteArrayData data[40];
    char stringdata0[616];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QChart_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QChart_t qt_meta_stringdata_QtCharts__QChart = {
    {
QT_MOC_LITERAL(0, 0, 16), // "QtCharts::QChart"
QT_MOC_LITERAL(1, 17, 15), // "plotAreaChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 8), // "plotArea"
QT_MOC_LITERAL(4, 43, 5), // "theme"
QT_MOC_LITERAL(5, 49, 18), // "QChart::ChartTheme"
QT_MOC_LITERAL(6, 68, 5), // "title"
QT_MOC_LITERAL(7, 74, 17), // "backgroundVisible"
QT_MOC_LITERAL(8, 92, 17), // "dropShadowEnabled"
QT_MOC_LITERAL(9, 110, 19), // "backgroundRoundness"
QT_MOC_LITERAL(10, 130, 16), // "animationOptions"
QT_MOC_LITERAL(11, 147, 24), // "QChart::AnimationOptions"
QT_MOC_LITERAL(12, 172, 17), // "animationDuration"
QT_MOC_LITERAL(13, 190, 20), // "animationEasingCurve"
QT_MOC_LITERAL(14, 211, 12), // "QEasingCurve"
QT_MOC_LITERAL(15, 224, 7), // "margins"
QT_MOC_LITERAL(16, 232, 8), // "QMargins"
QT_MOC_LITERAL(17, 241, 9), // "chartType"
QT_MOC_LITERAL(18, 251, 17), // "QChart::ChartType"
QT_MOC_LITERAL(19, 269, 25), // "plotAreaBackgroundVisible"
QT_MOC_LITERAL(20, 295, 15), // "localizeNumbers"
QT_MOC_LITERAL(21, 311, 6), // "locale"
QT_MOC_LITERAL(22, 318, 9), // "ChartType"
QT_MOC_LITERAL(23, 328, 18), // "ChartTypeUndefined"
QT_MOC_LITERAL(24, 347, 18), // "ChartTypeCartesian"
QT_MOC_LITERAL(25, 366, 14), // "ChartTypePolar"
QT_MOC_LITERAL(26, 381, 10), // "ChartTheme"
QT_MOC_LITERAL(27, 392, 15), // "ChartThemeLight"
QT_MOC_LITERAL(28, 408, 22), // "ChartThemeBlueCerulean"
QT_MOC_LITERAL(29, 431, 14), // "ChartThemeDark"
QT_MOC_LITERAL(30, 446, 19), // "ChartThemeBrownSand"
QT_MOC_LITERAL(31, 466, 17), // "ChartThemeBlueNcs"
QT_MOC_LITERAL(32, 484, 22), // "ChartThemeHighContrast"
QT_MOC_LITERAL(33, 507, 17), // "ChartThemeBlueIcy"
QT_MOC_LITERAL(34, 525, 12), // "ChartThemeQt"
QT_MOC_LITERAL(35, 538, 15), // "AnimationOption"
QT_MOC_LITERAL(36, 554, 11), // "NoAnimation"
QT_MOC_LITERAL(37, 566, 18), // "GridAxisAnimations"
QT_MOC_LITERAL(38, 585, 16), // "SeriesAnimations"
QT_MOC_LITERAL(39, 602, 13) // "AllAnimations"

    },
    "QtCharts::QChart\0plotAreaChanged\0\0"
    "plotArea\0theme\0QChart::ChartTheme\0"
    "title\0backgroundVisible\0dropShadowEnabled\0"
    "backgroundRoundness\0animationOptions\0"
    "QChart::AnimationOptions\0animationDuration\0"
    "animationEasingCurve\0QEasingCurve\0"
    "margins\0QMargins\0chartType\0QChart::ChartType\0"
    "plotAreaBackgroundVisible\0localizeNumbers\0"
    "locale\0ChartType\0ChartTypeUndefined\0"
    "ChartTypeCartesian\0ChartTypePolar\0"
    "ChartTheme\0ChartThemeLight\0"
    "ChartThemeBlueCerulean\0ChartThemeDark\0"
    "ChartThemeBrownSand\0ChartThemeBlueNcs\0"
    "ChartThemeHighContrast\0ChartThemeBlueIcy\0"
    "ChartThemeQt\0AnimationOption\0NoAnimation\0"
    "GridAxisAnimations\0SeriesAnimations\0"
    "AllAnimations"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QChart[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
      14,   22, // properties
       3,   78, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QRectF,    3,

 // properties: name, type, flags
       4, 0x80000000 | 5, 0x0009510b,
       6, QMetaType::QString, 0x00095103,
       7, QMetaType::Bool, 0x00095103,
       8, QMetaType::Bool, 0x00095103,
       9, QMetaType::QReal, 0x00095103,
      10, 0x80000000 | 11, 0x0009510b,
      12, QMetaType::Int, 0x00095103,
      13, 0x80000000 | 14, 0x0009510b,
      15, 0x80000000 | 16, 0x0009510b,
      17, 0x80000000 | 18, 0x00095009,
      19, QMetaType::Bool, 0x00095103,
      20, QMetaType::Bool, 0x00095103,
      21, QMetaType::QLocale, 0x00095103,
       3, QMetaType::QRectF, 0x00495103,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,
       0,

 // enums: name, alias, flags, count, data
      22,   22, 0x0,    3,   93,
      26,   26, 0x0,    8,   99,
      35,   35, 0x0,    4,  115,

 // enum data: key, value
      23, uint(QtCharts::QChart::ChartTypeUndefined),
      24, uint(QtCharts::QChart::ChartTypeCartesian),
      25, uint(QtCharts::QChart::ChartTypePolar),
      27, uint(QtCharts::QChart::ChartThemeLight),
      28, uint(QtCharts::QChart::ChartThemeBlueCerulean),
      29, uint(QtCharts::QChart::ChartThemeDark),
      30, uint(QtCharts::QChart::ChartThemeBrownSand),
      31, uint(QtCharts::QChart::ChartThemeBlueNcs),
      32, uint(QtCharts::QChart::ChartThemeHighContrast),
      33, uint(QtCharts::QChart::ChartThemeBlueIcy),
      34, uint(QtCharts::QChart::ChartThemeQt),
      36, uint(QtCharts::QChart::NoAnimation),
      37, uint(QtCharts::QChart::GridAxisAnimations),
      38, uint(QtCharts::QChart::SeriesAnimations),
      39, uint(QtCharts::QChart::AllAnimations),

       0        // eod
};

void QtCharts::QChart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QChart *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->plotAreaChanged((*reinterpret_cast< const QRectF(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QChart::*)(const QRectF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QChart::plotAreaChanged)) {
                *result = 0;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QChart *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QChart::ChartTheme*>(_v) = _t->theme(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->title(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isBackgroundVisible(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isDropShadowEnabled(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->backgroundRoundness(); break;
        case 5: *reinterpret_cast< QChart::AnimationOptions*>(_v) = _t->animationOptions(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->animationDuration(); break;
        case 7: *reinterpret_cast< QEasingCurve*>(_v) = _t->animationEasingCurve(); break;
        case 8: *reinterpret_cast< QMargins*>(_v) = _t->margins(); break;
        case 9: *reinterpret_cast< QChart::ChartType*>(_v) = _t->chartType(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->isPlotAreaBackgroundVisible(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->localizeNumbers(); break;
        case 12: *reinterpret_cast< QLocale*>(_v) = _t->locale(); break;
        case 13: *reinterpret_cast< QRectF*>(_v) = _t->plotArea(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QChart *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTheme(*reinterpret_cast< QChart::ChartTheme*>(_v)); break;
        case 1: _t->setTitle(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setBackgroundVisible(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setDropShadowEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setBackgroundRoundness(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setAnimationOptions(*reinterpret_cast< QChart::AnimationOptions*>(_v)); break;
        case 6: _t->setAnimationDuration(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setAnimationEasingCurve(*reinterpret_cast< QEasingCurve*>(_v)); break;
        case 8: _t->setMargins(*reinterpret_cast< QMargins*>(_v)); break;
        case 10: _t->setPlotAreaBackgroundVisible(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setLocalizeNumbers(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setLocale(*reinterpret_cast< QLocale*>(_v)); break;
        case 13: _t->setPlotArea(*reinterpret_cast< QRectF*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QChart::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsWidget::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QChart.data,
    qt_meta_data_QtCharts__QChart,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QChart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QChart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QChart.stringdata0))
        return static_cast<void*>(this);
    return QGraphicsWidget::qt_metacast(_clname);
}

int QtCharts::QChart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 14;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 14;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QChart::plotAreaChanged(const QRectF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
