/****************************************************************************
** Meta object code from reading C++ file 'qabstractbarseries.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/barchart/qabstractbarseries.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstractbarseries.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QAbstractBarSeries_t {
    QByteArrayData data[38];
    char stringdata0[503];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QAbstractBarSeries_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QAbstractBarSeries_t qt_meta_stringdata_QtCharts__QAbstractBarSeries = {
    {
QT_MOC_LITERAL(0, 0, 28), // "QtCharts::QAbstractBarSeries"
QT_MOC_LITERAL(1, 29, 7), // "clicked"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 5), // "index"
QT_MOC_LITERAL(4, 44, 8), // "QBarSet*"
QT_MOC_LITERAL(5, 53, 6), // "barset"
QT_MOC_LITERAL(6, 60, 7), // "hovered"
QT_MOC_LITERAL(7, 68, 6), // "status"
QT_MOC_LITERAL(8, 75, 7), // "pressed"
QT_MOC_LITERAL(9, 83, 8), // "released"
QT_MOC_LITERAL(10, 92, 13), // "doubleClicked"
QT_MOC_LITERAL(11, 106, 12), // "countChanged"
QT_MOC_LITERAL(12, 119, 20), // "labelsVisibleChanged"
QT_MOC_LITERAL(13, 140, 19), // "labelsFormatChanged"
QT_MOC_LITERAL(14, 160, 6), // "format"
QT_MOC_LITERAL(15, 167, 21), // "labelsPositionChanged"
QT_MOC_LITERAL(16, 189, 34), // "QAbstractBarSeries::LabelsPos..."
QT_MOC_LITERAL(17, 224, 8), // "position"
QT_MOC_LITERAL(18, 233, 18), // "labelsAngleChanged"
QT_MOC_LITERAL(19, 252, 5), // "angle"
QT_MOC_LITERAL(20, 258, 22), // "labelsPrecisionChanged"
QT_MOC_LITERAL(21, 281, 9), // "precision"
QT_MOC_LITERAL(22, 291, 12), // "barsetsAdded"
QT_MOC_LITERAL(23, 304, 15), // "QList<QBarSet*>"
QT_MOC_LITERAL(24, 320, 4), // "sets"
QT_MOC_LITERAL(25, 325, 14), // "barsetsRemoved"
QT_MOC_LITERAL(26, 340, 8), // "barWidth"
QT_MOC_LITERAL(27, 349, 5), // "count"
QT_MOC_LITERAL(28, 355, 13), // "labelsVisible"
QT_MOC_LITERAL(29, 369, 12), // "labelsFormat"
QT_MOC_LITERAL(30, 382, 14), // "labelsPosition"
QT_MOC_LITERAL(31, 397, 14), // "LabelsPosition"
QT_MOC_LITERAL(32, 412, 11), // "labelsAngle"
QT_MOC_LITERAL(33, 424, 15), // "labelsPrecision"
QT_MOC_LITERAL(34, 440, 12), // "LabelsCenter"
QT_MOC_LITERAL(35, 453, 15), // "LabelsInsideEnd"
QT_MOC_LITERAL(36, 469, 16), // "LabelsInsideBase"
QT_MOC_LITERAL(37, 486, 16) // "LabelsOutsideEnd"

    },
    "QtCharts::QAbstractBarSeries\0clicked\0"
    "\0index\0QBarSet*\0barset\0hovered\0status\0"
    "pressed\0released\0doubleClicked\0"
    "countChanged\0labelsVisibleChanged\0"
    "labelsFormatChanged\0format\0"
    "labelsPositionChanged\0"
    "QAbstractBarSeries::LabelsPosition\0"
    "position\0labelsAngleChanged\0angle\0"
    "labelsPrecisionChanged\0precision\0"
    "barsetsAdded\0QList<QBarSet*>\0sets\0"
    "barsetsRemoved\0barWidth\0count\0"
    "labelsVisible\0labelsFormat\0labelsPosition\0"
    "LabelsPosition\0labelsAngle\0labelsPrecision\0"
    "LabelsCenter\0LabelsInsideEnd\0"
    "LabelsInsideBase\0LabelsOutsideEnd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QAbstractBarSeries[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       7,  126, // properties
       1,  154, // enums/sets
       0,    0, // constructors
       0,       // flags
      13,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   79,    2, 0x06 /* Public */,
       6,    3,   84,    2, 0x06 /* Public */,
       8,    2,   91,    2, 0x06 /* Public */,
       9,    2,   96,    2, 0x06 /* Public */,
      10,    2,  101,    2, 0x06 /* Public */,
      11,    0,  106,    2, 0x06 /* Public */,
      12,    0,  107,    2, 0x06 /* Public */,
      13,    1,  108,    2, 0x06 /* Public */,
      15,    1,  111,    2, 0x06 /* Public */,
      18,    1,  114,    2, 0x06 /* Public */,
      20,    1,  117,    2, 0x06 /* Public */,
      22,    1,  120,    2, 0x06 /* Public */,
      25,    1,  123,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int, 0x80000000 | 4,    7,    3,    5,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 4,    3,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, QMetaType::QReal,   19,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void, 0x80000000 | 23,   24,
    QMetaType::Void, 0x80000000 | 23,   24,

 // properties: name, type, flags
      26, QMetaType::QReal, 0x00095103,
      27, QMetaType::Int, 0x00495001,
      28, QMetaType::Bool, 0x00495103,
      29, QMetaType::QString, 0x00495103,
      30, 0x80000000 | 31, 0x0049510b,
      32, QMetaType::QReal, 0x00495103,
      33, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       0,
       5,
       6,
       7,
       8,
       9,
      10,

 // enums: name, alias, flags, count, data
      31,   31, 0x0,    4,  159,

 // enum data: key, value
      34, uint(QtCharts::QAbstractBarSeries::LabelsCenter),
      35, uint(QtCharts::QAbstractBarSeries::LabelsInsideEnd),
      36, uint(QtCharts::QAbstractBarSeries::LabelsInsideBase),
      37, uint(QtCharts::QAbstractBarSeries::LabelsOutsideEnd),

       0        // eod
};

void QtCharts::QAbstractBarSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QAbstractBarSeries *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QBarSet*(*)>(_a[2]))); break;
        case 1: _t->hovered((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QBarSet*(*)>(_a[3]))); break;
        case 2: _t->pressed((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QBarSet*(*)>(_a[2]))); break;
        case 3: _t->released((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QBarSet*(*)>(_a[2]))); break;
        case 4: _t->doubleClicked((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QBarSet*(*)>(_a[2]))); break;
        case 5: _t->countChanged(); break;
        case 6: _t->labelsVisibleChanged(); break;
        case 7: _t->labelsFormatChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->labelsPositionChanged((*reinterpret_cast< QAbstractBarSeries::LabelsPosition(*)>(_a[1]))); break;
        case 9: _t->labelsAngleChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 10: _t->labelsPrecisionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->barsetsAdded((*reinterpret_cast< QList<QBarSet*>(*)>(_a[1]))); break;
        case 12: _t->barsetsRemoved((*reinterpret_cast< QList<QBarSet*>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QAbstractBarSeries::*)(int , QBarSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(bool , int , QBarSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::hovered)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(int , QBarSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::pressed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(int , QBarSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::released)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(int , QBarSet * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::doubleClicked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::countChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::labelsVisibleChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::labelsFormatChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(QAbstractBarSeries::LabelsPosition );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::labelsPositionChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::labelsAngleChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::labelsPrecisionChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(QList<QBarSet*> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::barsetsAdded)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QAbstractBarSeries::*)(QList<QBarSet*> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractBarSeries::barsetsRemoved)) {
                *result = 12;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QAbstractBarSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->barWidth(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isLabelsVisible(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->labelsFormat(); break;
        case 4: *reinterpret_cast< LabelsPosition*>(_v) = _t->labelsPosition(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->labelsAngle(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->labelsPrecision(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QAbstractBarSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBarWidth(*reinterpret_cast< qreal*>(_v)); break;
        case 2: _t->setLabelsVisible(*reinterpret_cast< bool*>(_v)); break;
        case 3: _t->setLabelsFormat(*reinterpret_cast< QString*>(_v)); break;
        case 4: _t->setLabelsPosition(*reinterpret_cast< LabelsPosition*>(_v)); break;
        case 5: _t->setLabelsAngle(*reinterpret_cast< qreal*>(_v)); break;
        case 6: _t->setLabelsPrecision(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QAbstractBarSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractSeries::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QAbstractBarSeries.data,
    qt_meta_data_QtCharts__QAbstractBarSeries,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QAbstractBarSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QAbstractBarSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QAbstractBarSeries.stringdata0))
        return static_cast<void*>(this);
    return QAbstractSeries::qt_metacast(_clname);
}

int QtCharts::QAbstractBarSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QAbstractBarSeries::clicked(int _t1, QBarSet * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::QAbstractBarSeries::hovered(bool _t1, int _t2, QBarSet * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QAbstractBarSeries::pressed(int _t1, QBarSet * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::QAbstractBarSeries::released(int _t1, QBarSet * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::QAbstractBarSeries::doubleClicked(int _t1, QBarSet * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::QAbstractBarSeries::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QtCharts::QAbstractBarSeries::labelsVisibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QtCharts::QAbstractBarSeries::labelsFormatChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QtCharts::QAbstractBarSeries::labelsPositionChanged(QAbstractBarSeries::LabelsPosition _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QtCharts::QAbstractBarSeries::labelsAngleChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void QtCharts::QAbstractBarSeries::labelsPrecisionChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void QtCharts::QAbstractBarSeries::barsetsAdded(QList<QBarSet*> _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QtCharts::QAbstractBarSeries::barsetsRemoved(QList<QBarSet*> _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
