/* This file was generated by syncqt. */
#ifndef QT_QTCHARTS_VERSION_H
#define QT_QTCHARTS_VERSION_H

#define QTCHARTS_VERSION_STR "5.15.4"

#define QTCHARTS_VERSION 0x050F04

#endif // QT_QTCHARTS_VERSION_H
