/****************************************************************************
** Meta object code from reading C++ file 'qabstractaxis.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/axis/qabstractaxis.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qabstractaxis.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QAbstractAxis_t {
    QByteArrayData data[63];
    char stringdata0[918];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QAbstractAxis_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QAbstractAxis_t qt_meta_stringdata_QtCharts__QAbstractAxis = {
    {
QT_MOC_LITERAL(0, 0, 23), // "QtCharts::QAbstractAxis"
QT_MOC_LITERAL(1, 24, 14), // "visibleChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 7), // "visible"
QT_MOC_LITERAL(4, 48, 14), // "linePenChanged"
QT_MOC_LITERAL(5, 63, 3), // "pen"
QT_MOC_LITERAL(6, 67, 18), // "lineVisibleChanged"
QT_MOC_LITERAL(7, 86, 20), // "labelsVisibleChanged"
QT_MOC_LITERAL(8, 107, 18), // "labelsBrushChanged"
QT_MOC_LITERAL(9, 126, 5), // "brush"
QT_MOC_LITERAL(10, 132, 17), // "labelsFontChanged"
QT_MOC_LITERAL(11, 150, 18), // "labelsAngleChanged"
QT_MOC_LITERAL(12, 169, 5), // "angle"
QT_MOC_LITERAL(13, 175, 18), // "gridLinePenChanged"
QT_MOC_LITERAL(14, 194, 18), // "gridVisibleChanged"
QT_MOC_LITERAL(15, 213, 23), // "minorGridVisibleChanged"
QT_MOC_LITERAL(16, 237, 23), // "minorGridLinePenChanged"
QT_MOC_LITERAL(17, 261, 20), // "gridLineColorChanged"
QT_MOC_LITERAL(18, 282, 5), // "color"
QT_MOC_LITERAL(19, 288, 25), // "minorGridLineColorChanged"
QT_MOC_LITERAL(20, 314, 12), // "colorChanged"
QT_MOC_LITERAL(21, 327, 18), // "labelsColorChanged"
QT_MOC_LITERAL(22, 346, 16), // "titleTextChanged"
QT_MOC_LITERAL(23, 363, 5), // "title"
QT_MOC_LITERAL(24, 369, 17), // "titleBrushChanged"
QT_MOC_LITERAL(25, 387, 19), // "titleVisibleChanged"
QT_MOC_LITERAL(26, 407, 16), // "titleFontChanged"
QT_MOC_LITERAL(27, 424, 4), // "font"
QT_MOC_LITERAL(28, 429, 20), // "shadesVisibleChanged"
QT_MOC_LITERAL(29, 450, 18), // "shadesColorChanged"
QT_MOC_LITERAL(30, 469, 24), // "shadesBorderColorChanged"
QT_MOC_LITERAL(31, 494, 16), // "shadesPenChanged"
QT_MOC_LITERAL(32, 511, 18), // "shadesBrushChanged"
QT_MOC_LITERAL(33, 530, 14), // "reverseChanged"
QT_MOC_LITERAL(34, 545, 7), // "reverse"
QT_MOC_LITERAL(35, 553, 21), // "labelsEditableChanged"
QT_MOC_LITERAL(36, 575, 8), // "editable"
QT_MOC_LITERAL(37, 584, 11), // "lineVisible"
QT_MOC_LITERAL(38, 596, 7), // "linePen"
QT_MOC_LITERAL(39, 604, 13), // "labelsVisible"
QT_MOC_LITERAL(40, 618, 11), // "labelsBrush"
QT_MOC_LITERAL(41, 630, 11), // "labelsAngle"
QT_MOC_LITERAL(42, 642, 10), // "labelsFont"
QT_MOC_LITERAL(43, 653, 11), // "labelsColor"
QT_MOC_LITERAL(44, 665, 11), // "gridVisible"
QT_MOC_LITERAL(45, 677, 11), // "gridLinePen"
QT_MOC_LITERAL(46, 689, 16), // "minorGridVisible"
QT_MOC_LITERAL(47, 706, 16), // "minorGridLinePen"
QT_MOC_LITERAL(48, 723, 13), // "gridLineColor"
QT_MOC_LITERAL(49, 737, 18), // "minorGridLineColor"
QT_MOC_LITERAL(50, 756, 13), // "shadesVisible"
QT_MOC_LITERAL(51, 770, 11), // "shadesColor"
QT_MOC_LITERAL(52, 782, 17), // "shadesBorderColor"
QT_MOC_LITERAL(53, 800, 9), // "shadesPen"
QT_MOC_LITERAL(54, 810, 11), // "shadesBrush"
QT_MOC_LITERAL(55, 822, 9), // "titleText"
QT_MOC_LITERAL(56, 832, 10), // "titleBrush"
QT_MOC_LITERAL(57, 843, 12), // "titleVisible"
QT_MOC_LITERAL(58, 856, 9), // "titleFont"
QT_MOC_LITERAL(59, 866, 11), // "orientation"
QT_MOC_LITERAL(60, 878, 15), // "Qt::Orientation"
QT_MOC_LITERAL(61, 894, 9), // "alignment"
QT_MOC_LITERAL(62, 904, 13) // "Qt::Alignment"

    },
    "QtCharts::QAbstractAxis\0visibleChanged\0"
    "\0visible\0linePenChanged\0pen\0"
    "lineVisibleChanged\0labelsVisibleChanged\0"
    "labelsBrushChanged\0brush\0labelsFontChanged\0"
    "labelsAngleChanged\0angle\0gridLinePenChanged\0"
    "gridVisibleChanged\0minorGridVisibleChanged\0"
    "minorGridLinePenChanged\0gridLineColorChanged\0"
    "color\0minorGridLineColorChanged\0"
    "colorChanged\0labelsColorChanged\0"
    "titleTextChanged\0title\0titleBrushChanged\0"
    "titleVisibleChanged\0titleFontChanged\0"
    "font\0shadesVisibleChanged\0shadesColorChanged\0"
    "shadesBorderColorChanged\0shadesPenChanged\0"
    "shadesBrushChanged\0reverseChanged\0"
    "reverse\0labelsEditableChanged\0editable\0"
    "lineVisible\0linePen\0labelsVisible\0"
    "labelsBrush\0labelsAngle\0labelsFont\0"
    "labelsColor\0gridVisible\0gridLinePen\0"
    "minorGridVisible\0minorGridLinePen\0"
    "gridLineColor\0minorGridLineColor\0"
    "shadesVisible\0shadesColor\0shadesBorderColor\0"
    "shadesPen\0shadesBrush\0titleText\0"
    "titleBrush\0titleVisible\0titleFont\0"
    "orientation\0Qt::Orientation\0alignment\0"
    "Qt::Alignment"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QAbstractAxis[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      26,   14, // methods
      27,  222, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      26,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  144,    2, 0x06 /* Public */,
       4,    1,  147,    2, 0x06 /* Public */,
       6,    1,  150,    2, 0x06 /* Public */,
       7,    1,  153,    2, 0x06 /* Public */,
       8,    1,  156,    2, 0x06 /* Public */,
      10,    1,  159,    2, 0x06 /* Public */,
      11,    1,  162,    2, 0x06 /* Public */,
      13,    1,  165,    2, 0x06 /* Public */,
      14,    1,  168,    2, 0x06 /* Public */,
      15,    1,  171,    2, 0x06 /* Public */,
      16,    1,  174,    2, 0x06 /* Public */,
      17,    1,  177,    2, 0x06 /* Public */,
      19,    1,  180,    2, 0x06 /* Public */,
      20,    1,  183,    2, 0x06 /* Public */,
      21,    1,  186,    2, 0x06 /* Public */,
      22,    1,  189,    2, 0x06 /* Public */,
      24,    1,  192,    2, 0x06 /* Public */,
      25,    1,  195,    2, 0x06 /* Public */,
      26,    1,  198,    2, 0x06 /* Public */,
      28,    1,  201,    2, 0x06 /* Public */,
      29,    1,  204,    2, 0x06 /* Public */,
      30,    1,  207,    2, 0x06 /* Public */,
      31,    1,  210,    2, 0x06 /* Public */,
      32,    1,  213,    2, 0x06 /* Public */,
      33,    1,  216,    2, 0x06 /* Public */,
      35,    1,  219,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QPen,    5,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QBrush,    9,
    QMetaType::Void, QMetaType::QFont,    5,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::QPen,    5,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QPen,    5,
    QMetaType::Void, QMetaType::QColor,   18,
    QMetaType::Void, QMetaType::QColor,   18,
    QMetaType::Void, QMetaType::QColor,   18,
    QMetaType::Void, QMetaType::QColor,   18,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QBrush,    9,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QFont,   27,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::QColor,   18,
    QMetaType::Void, QMetaType::QColor,   18,
    QMetaType::Void, QMetaType::QPen,    5,
    QMetaType::Void, QMetaType::QBrush,    9,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   36,

 // properties: name, type, flags
       3, QMetaType::Bool, 0x00495103,
      37, QMetaType::Bool, 0x00495103,
      38, QMetaType::QPen, 0x00495103,
      18, QMetaType::QColor, 0x00495003,
      39, QMetaType::Bool, 0x00495103,
      40, QMetaType::QBrush, 0x00495103,
      41, QMetaType::Int, 0x00495103,
      42, QMetaType::QFont, 0x00495103,
      43, QMetaType::QColor, 0x00495103,
      44, QMetaType::Bool, 0x00495003,
      45, QMetaType::QPen, 0x00495103,
      46, QMetaType::Bool, 0x00495003,
      47, QMetaType::QPen, 0x00495103,
      48, QMetaType::QColor, 0x00495103,
      49, QMetaType::QColor, 0x00495103,
      50, QMetaType::Bool, 0x00495103,
      51, QMetaType::QColor, 0x00495103,
      52, QMetaType::QColor, 0x00495103,
      53, QMetaType::QPen, 0x00495103,
      54, QMetaType::QBrush, 0x00495103,
      55, QMetaType::QString, 0x00495103,
      56, QMetaType::QBrush, 0x00495103,
      57, QMetaType::Bool, 0x00495103,
      58, QMetaType::QFont, 0x00495103,
      59, 0x80000000 | 60, 0x00095009,
      61, 0x80000000 | 62, 0x00095009,
      34, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       2,
       1,
      13,
       3,
       4,
       6,
       5,
      14,
       8,
       7,
       9,
      10,
      11,
      12,
      19,
      20,
      21,
      22,
      23,
      15,
      16,
      17,
      18,
       0,
       0,
      24,

       0        // eod
};

void QtCharts::QAbstractAxis::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QAbstractAxis *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->visibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->linePenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 2: _t->lineVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->labelsVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->labelsBrushChanged((*reinterpret_cast< const QBrush(*)>(_a[1]))); break;
        case 5: _t->labelsFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 6: _t->labelsAngleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->gridLinePenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 8: _t->gridVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->minorGridVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->minorGridLinePenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 11: _t->gridLineColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 12: _t->minorGridLineColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 13: _t->colorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 14: _t->labelsColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 15: _t->titleTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->titleBrushChanged((*reinterpret_cast< const QBrush(*)>(_a[1]))); break;
        case 17: _t->titleVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->titleFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 19: _t->shadesVisibleChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->shadesColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 21: _t->shadesBorderColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 22: _t->shadesPenChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        case 23: _t->shadesBrushChanged((*reinterpret_cast< const QBrush(*)>(_a[1]))); break;
        case 24: _t->reverseChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->labelsEditableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::visibleChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QPen & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::linePenChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::lineVisibleChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::labelsVisibleChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QBrush & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::labelsBrushChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::labelsFontChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::labelsAngleChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QPen & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::gridLinePenChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::gridVisibleChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::minorGridVisibleChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QPen & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::minorGridLinePenChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::gridLineColorChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::minorGridLineColorChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::colorChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::labelsColorChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::titleTextChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QBrush & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::titleBrushChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::titleVisibleChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::titleFontChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::shadesVisibleChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::shadesColorChanged)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::shadesBorderColorChanged)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QPen & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::shadesPenChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(const QBrush & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::shadesBrushChanged)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::reverseChanged)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (QAbstractAxis::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QAbstractAxis::labelsEditableChanged)) {
                *result = 25;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QAbstractAxis *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isVisible(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isLineVisible(); break;
        case 2: *reinterpret_cast< QPen*>(_v) = _t->linePen(); break;
        case 3: *reinterpret_cast< QColor*>(_v) = _t->linePenColor(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->labelsVisible(); break;
        case 5: *reinterpret_cast< QBrush*>(_v) = _t->labelsBrush(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->labelsAngle(); break;
        case 7: *reinterpret_cast< QFont*>(_v) = _t->labelsFont(); break;
        case 8: *reinterpret_cast< QColor*>(_v) = _t->labelsColor(); break;
        case 9: *reinterpret_cast< bool*>(_v) = _t->isGridLineVisible(); break;
        case 10: *reinterpret_cast< QPen*>(_v) = _t->gridLinePen(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->isMinorGridLineVisible(); break;
        case 12: *reinterpret_cast< QPen*>(_v) = _t->minorGridLinePen(); break;
        case 13: *reinterpret_cast< QColor*>(_v) = _t->gridLineColor(); break;
        case 14: *reinterpret_cast< QColor*>(_v) = _t->minorGridLineColor(); break;
        case 15: *reinterpret_cast< bool*>(_v) = _t->shadesVisible(); break;
        case 16: *reinterpret_cast< QColor*>(_v) = _t->shadesColor(); break;
        case 17: *reinterpret_cast< QColor*>(_v) = _t->shadesBorderColor(); break;
        case 18: *reinterpret_cast< QPen*>(_v) = _t->shadesPen(); break;
        case 19: *reinterpret_cast< QBrush*>(_v) = _t->shadesBrush(); break;
        case 20: *reinterpret_cast< QString*>(_v) = _t->titleText(); break;
        case 21: *reinterpret_cast< QBrush*>(_v) = _t->titleBrush(); break;
        case 22: *reinterpret_cast< bool*>(_v) = _t->isTitleVisible(); break;
        case 23: *reinterpret_cast< QFont*>(_v) = _t->titleFont(); break;
        case 24: *reinterpret_cast< Qt::Orientation*>(_v) = _t->orientation(); break;
        case 25: *reinterpret_cast< Qt::Alignment*>(_v) = _t->alignment(); break;
        case 26: *reinterpret_cast< bool*>(_v) = _t->isReverse(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QAbstractAxis *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setVisible(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setLineVisible(*reinterpret_cast< bool*>(_v)); break;
        case 2: _t->setLinePen(*reinterpret_cast< QPen*>(_v)); break;
        case 3: _t->setLinePenColor(*reinterpret_cast< QColor*>(_v)); break;
        case 4: _t->setLabelsVisible(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setLabelsBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 6: _t->setLabelsAngle(*reinterpret_cast< int*>(_v)); break;
        case 7: _t->setLabelsFont(*reinterpret_cast< QFont*>(_v)); break;
        case 8: _t->setLabelsColor(*reinterpret_cast< QColor*>(_v)); break;
        case 9: _t->setGridLineVisible(*reinterpret_cast< bool*>(_v)); break;
        case 10: _t->setGridLinePen(*reinterpret_cast< QPen*>(_v)); break;
        case 11: _t->setMinorGridLineVisible(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setMinorGridLinePen(*reinterpret_cast< QPen*>(_v)); break;
        case 13: _t->setGridLineColor(*reinterpret_cast< QColor*>(_v)); break;
        case 14: _t->setMinorGridLineColor(*reinterpret_cast< QColor*>(_v)); break;
        case 15: _t->setShadesVisible(*reinterpret_cast< bool*>(_v)); break;
        case 16: _t->setShadesColor(*reinterpret_cast< QColor*>(_v)); break;
        case 17: _t->setShadesBorderColor(*reinterpret_cast< QColor*>(_v)); break;
        case 18: _t->setShadesPen(*reinterpret_cast< QPen*>(_v)); break;
        case 19: _t->setShadesBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 20: _t->setTitleText(*reinterpret_cast< QString*>(_v)); break;
        case 21: _t->setTitleBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 22: _t->setTitleVisible(*reinterpret_cast< bool*>(_v)); break;
        case 23: _t->setTitleFont(*reinterpret_cast< QFont*>(_v)); break;
        case 26: _t->setReverse(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QAbstractAxis::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QAbstractAxis.data,
    qt_meta_data_QtCharts__QAbstractAxis,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QAbstractAxis::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QAbstractAxis::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QAbstractAxis.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QtCharts::QAbstractAxis::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 26;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 27;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 27;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QAbstractAxis::visibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::QAbstractAxis::linePenChanged(const QPen & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QAbstractAxis::lineVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::QAbstractAxis::labelsVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::QAbstractAxis::labelsBrushChanged(const QBrush & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::QAbstractAxis::labelsFontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QtCharts::QAbstractAxis::labelsAngleChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QtCharts::QAbstractAxis::gridLinePenChanged(const QPen & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QtCharts::QAbstractAxis::gridVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QtCharts::QAbstractAxis::minorGridVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void QtCharts::QAbstractAxis::minorGridLinePenChanged(const QPen & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void QtCharts::QAbstractAxis::gridLineColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QtCharts::QAbstractAxis::minorGridLineColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void QtCharts::QAbstractAxis::colorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void QtCharts::QAbstractAxis::labelsColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void QtCharts::QAbstractAxis::titleTextChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void QtCharts::QAbstractAxis::titleBrushChanged(const QBrush & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void QtCharts::QAbstractAxis::titleVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void QtCharts::QAbstractAxis::titleFontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void QtCharts::QAbstractAxis::shadesVisibleChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void QtCharts::QAbstractAxis::shadesColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void QtCharts::QAbstractAxis::shadesBorderColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void QtCharts::QAbstractAxis::shadesPenChanged(const QPen & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void QtCharts::QAbstractAxis::shadesBrushChanged(const QBrush & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void QtCharts::QAbstractAxis::reverseChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void QtCharts::QAbstractAxis::labelsEditableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
