/****************************************************************************
** Meta object code from reading C++ file 'qbarset.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/barchart/qbarset.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qbarset.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QBarSet_t {
    QByteArrayData data[29];
    char stringdata0[312];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QBarSet_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QBarSet_t qt_meta_stringdata_QtCharts__QBarSet = {
    {
QT_MOC_LITERAL(0, 0, 17), // "QtCharts::QBarSet"
QT_MOC_LITERAL(1, 18, 7), // "clicked"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 5), // "index"
QT_MOC_LITERAL(4, 33, 7), // "hovered"
QT_MOC_LITERAL(5, 41, 6), // "status"
QT_MOC_LITERAL(6, 48, 7), // "pressed"
QT_MOC_LITERAL(7, 56, 8), // "released"
QT_MOC_LITERAL(8, 65, 13), // "doubleClicked"
QT_MOC_LITERAL(9, 79, 10), // "penChanged"
QT_MOC_LITERAL(10, 90, 12), // "brushChanged"
QT_MOC_LITERAL(11, 103, 12), // "labelChanged"
QT_MOC_LITERAL(12, 116, 17), // "labelBrushChanged"
QT_MOC_LITERAL(13, 134, 16), // "labelFontChanged"
QT_MOC_LITERAL(14, 151, 12), // "colorChanged"
QT_MOC_LITERAL(15, 164, 5), // "color"
QT_MOC_LITERAL(16, 170, 18), // "borderColorChanged"
QT_MOC_LITERAL(17, 189, 17), // "labelColorChanged"
QT_MOC_LITERAL(18, 207, 11), // "valuesAdded"
QT_MOC_LITERAL(19, 219, 5), // "count"
QT_MOC_LITERAL(20, 225, 13), // "valuesRemoved"
QT_MOC_LITERAL(21, 239, 12), // "valueChanged"
QT_MOC_LITERAL(22, 252, 5), // "label"
QT_MOC_LITERAL(23, 258, 3), // "pen"
QT_MOC_LITERAL(24, 262, 5), // "brush"
QT_MOC_LITERAL(25, 268, 10), // "labelBrush"
QT_MOC_LITERAL(26, 279, 9), // "labelFont"
QT_MOC_LITERAL(27, 289, 11), // "borderColor"
QT_MOC_LITERAL(28, 301, 10) // "labelColor"

    },
    "QtCharts::QBarSet\0clicked\0\0index\0"
    "hovered\0status\0pressed\0released\0"
    "doubleClicked\0penChanged\0brushChanged\0"
    "labelChanged\0labelBrushChanged\0"
    "labelFontChanged\0colorChanged\0color\0"
    "borderColorChanged\0labelColorChanged\0"
    "valuesAdded\0count\0valuesRemoved\0"
    "valueChanged\0label\0pen\0brush\0labelBrush\0"
    "labelFont\0borderColor\0labelColor"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QBarSet[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       8,  138, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      16,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x06 /* Public */,
       4,    2,   97,    2, 0x06 /* Public */,
       6,    1,  102,    2, 0x06 /* Public */,
       7,    1,  105,    2, 0x06 /* Public */,
       8,    1,  108,    2, 0x06 /* Public */,
       9,    0,  111,    2, 0x06 /* Public */,
      10,    0,  112,    2, 0x06 /* Public */,
      11,    0,  113,    2, 0x06 /* Public */,
      12,    0,  114,    2, 0x06 /* Public */,
      13,    0,  115,    2, 0x06 /* Public */,
      14,    1,  116,    2, 0x06 /* Public */,
      16,    1,  119,    2, 0x06 /* Public */,
      17,    1,  122,    2, 0x06 /* Public */,
      18,    2,  125,    2, 0x06 /* Public */,
      20,    2,  130,    2, 0x06 /* Public */,
      21,    1,  135,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Bool, QMetaType::Int,    5,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QColor,   15,
    QMetaType::Void, QMetaType::QColor,   15,
    QMetaType::Void, QMetaType::QColor,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,   19,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    3,   19,
    QMetaType::Void, QMetaType::Int,    3,

 // properties: name, type, flags
      22, QMetaType::QString, 0x00495103,
      23, QMetaType::QPen, 0x00495103,
      24, QMetaType::QBrush, 0x00495103,
      25, QMetaType::QBrush, 0x00495103,
      26, QMetaType::QFont, 0x00495103,
      15, QMetaType::QColor, 0x00495103,
      27, QMetaType::QColor, 0x00495103,
      28, QMetaType::QColor, 0x00495103,

 // properties: notify_signal_id
       7,
       5,
       6,
       8,
       9,
      10,
      11,
      12,

       0        // eod
};

void QtCharts::QBarSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QBarSet *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->hovered((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->pressed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->released((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->doubleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->penChanged(); break;
        case 6: _t->brushChanged(); break;
        case 7: _t->labelChanged(); break;
        case 8: _t->labelBrushChanged(); break;
        case 9: _t->labelFontChanged(); break;
        case 10: _t->colorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 11: _t->borderColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 12: _t->labelColorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 13: _t->valuesAdded((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 14: _t->valuesRemoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 15: _t->valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QBarSet::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(bool , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::hovered)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::pressed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::released)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::doubleClicked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::penChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::brushChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::labelChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::labelBrushChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::labelFontChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::colorChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::borderColorChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::labelColorChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::valuesAdded)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::valuesRemoved)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (QBarSet::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QBarSet::valueChanged)) {
                *result = 15;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QBarSet *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->label(); break;
        case 1: *reinterpret_cast< QPen*>(_v) = _t->pen(); break;
        case 2: *reinterpret_cast< QBrush*>(_v) = _t->brush(); break;
        case 3: *reinterpret_cast< QBrush*>(_v) = _t->labelBrush(); break;
        case 4: *reinterpret_cast< QFont*>(_v) = _t->labelFont(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 6: *reinterpret_cast< QColor*>(_v) = _t->borderColor(); break;
        case 7: *reinterpret_cast< QColor*>(_v) = _t->labelColor(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QBarSet *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLabel(*reinterpret_cast< QString*>(_v)); break;
        case 1: _t->setPen(*reinterpret_cast< QPen*>(_v)); break;
        case 2: _t->setBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 3: _t->setLabelBrush(*reinterpret_cast< QBrush*>(_v)); break;
        case 4: _t->setLabelFont(*reinterpret_cast< QFont*>(_v)); break;
        case 5: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 6: _t->setBorderColor(*reinterpret_cast< QColor*>(_v)); break;
        case 7: _t->setLabelColor(*reinterpret_cast< QColor*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QBarSet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QBarSet.data,
    qt_meta_data_QtCharts__QBarSet,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QBarSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QBarSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QBarSet.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QtCharts::QBarSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 8;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 8;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QBarSet::clicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::QBarSet::hovered(bool _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QBarSet::pressed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::QBarSet::released(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::QBarSet::doubleClicked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::QBarSet::penChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QtCharts::QBarSet::brushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QtCharts::QBarSet::labelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QtCharts::QBarSet::labelBrushChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QtCharts::QBarSet::labelFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QtCharts::QBarSet::colorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void QtCharts::QBarSet::borderColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QtCharts::QBarSet::labelColorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void QtCharts::QBarSet::valuesAdded(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void QtCharts::QBarSet::valuesRemoved(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void QtCharts::QBarSet::valueChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
