/****************************************************************************
** Meta object code from reading C++ file 'qxyseries.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../git/src/charts/xychart/qxyseries.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qxyseries.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QtCharts__QXYSeries_t {
    QByteArrayData data[35];
    char stringdata0[454];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QtCharts__QXYSeries_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QtCharts__QXYSeries_t qt_meta_stringdata_QtCharts__QXYSeries = {
    {
QT_MOC_LITERAL(0, 0, 19), // "QtCharts::QXYSeries"
QT_MOC_LITERAL(1, 20, 7), // "clicked"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 5), // "point"
QT_MOC_LITERAL(4, 35, 7), // "hovered"
QT_MOC_LITERAL(5, 43, 5), // "state"
QT_MOC_LITERAL(6, 49, 7), // "pressed"
QT_MOC_LITERAL(7, 57, 8), // "released"
QT_MOC_LITERAL(8, 66, 13), // "doubleClicked"
QT_MOC_LITERAL(9, 80, 13), // "pointReplaced"
QT_MOC_LITERAL(10, 94, 5), // "index"
QT_MOC_LITERAL(11, 100, 12), // "pointRemoved"
QT_MOC_LITERAL(12, 113, 10), // "pointAdded"
QT_MOC_LITERAL(13, 124, 12), // "colorChanged"
QT_MOC_LITERAL(14, 137, 5), // "color"
QT_MOC_LITERAL(15, 143, 14), // "pointsReplaced"
QT_MOC_LITERAL(16, 158, 24), // "pointLabelsFormatChanged"
QT_MOC_LITERAL(17, 183, 6), // "format"
QT_MOC_LITERAL(18, 190, 28), // "pointLabelsVisibilityChanged"
QT_MOC_LITERAL(19, 219, 7), // "visible"
QT_MOC_LITERAL(20, 227, 22), // "pointLabelsFontChanged"
QT_MOC_LITERAL(21, 250, 4), // "font"
QT_MOC_LITERAL(22, 255, 23), // "pointLabelsColorChanged"
QT_MOC_LITERAL(23, 279, 26), // "pointLabelsClippingChanged"
QT_MOC_LITERAL(24, 306, 8), // "clipping"
QT_MOC_LITERAL(25, 315, 13), // "pointsRemoved"
QT_MOC_LITERAL(26, 329, 5), // "count"
QT_MOC_LITERAL(27, 335, 10), // "penChanged"
QT_MOC_LITERAL(28, 346, 3), // "pen"
QT_MOC_LITERAL(29, 350, 13), // "pointsVisible"
QT_MOC_LITERAL(30, 364, 17), // "pointLabelsFormat"
QT_MOC_LITERAL(31, 382, 18), // "pointLabelsVisible"
QT_MOC_LITERAL(32, 401, 15), // "pointLabelsFont"
QT_MOC_LITERAL(33, 417, 16), // "pointLabelsColor"
QT_MOC_LITERAL(34, 434, 19) // "pointLabelsClipping"

    },
    "QtCharts::QXYSeries\0clicked\0\0point\0"
    "hovered\0state\0pressed\0released\0"
    "doubleClicked\0pointReplaced\0index\0"
    "pointRemoved\0pointAdded\0colorChanged\0"
    "color\0pointsReplaced\0pointLabelsFormatChanged\0"
    "format\0pointLabelsVisibilityChanged\0"
    "visible\0pointLabelsFontChanged\0font\0"
    "pointLabelsColorChanged\0"
    "pointLabelsClippingChanged\0clipping\0"
    "pointsRemoved\0count\0penChanged\0pen\0"
    "pointsVisible\0pointLabelsFormat\0"
    "pointLabelsVisible\0pointLabelsFont\0"
    "pointLabelsColor\0pointLabelsClipping"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QtCharts__QXYSeries[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       7,  152, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      17,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,
       4,    2,  102,    2, 0x06 /* Public */,
       6,    1,  107,    2, 0x06 /* Public */,
       7,    1,  110,    2, 0x06 /* Public */,
       8,    1,  113,    2, 0x06 /* Public */,
       9,    1,  116,    2, 0x06 /* Public */,
      11,    1,  119,    2, 0x06 /* Public */,
      12,    1,  122,    2, 0x06 /* Public */,
      13,    1,  125,    2, 0x06 /* Public */,
      15,    0,  128,    2, 0x06 /* Public */,
      16,    1,  129,    2, 0x06 /* Public */,
      18,    1,  132,    2, 0x06 /* Public */,
      20,    1,  135,    2, 0x06 /* Public */,
      22,    1,  138,    2, 0x06 /* Public */,
      23,    1,  141,    2, 0x06 /* Public */,
      25,    2,  144,    2, 0x06 /* Public */,
      27,    1,  149,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QPointF,    3,
    QMetaType::Void, QMetaType::QPointF, QMetaType::Bool,    3,    5,
    QMetaType::Void, QMetaType::QPointF,    3,
    QMetaType::Void, QMetaType::QPointF,    3,
    QMetaType::Void, QMetaType::QPointF,    3,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::Int,   10,
    QMetaType::Void, QMetaType::QColor,   14,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   17,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::QFont,   21,
    QMetaType::Void, QMetaType::QColor,   14,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   10,   26,
    QMetaType::Void, QMetaType::QPen,   28,

 // properties: name, type, flags
      29, QMetaType::Bool, 0x00095103,
      14, QMetaType::QColor, 0x00495103,
      30, QMetaType::QString, 0x00495103,
      31, QMetaType::Bool, 0x00495103,
      32, QMetaType::QFont, 0x00495103,
      33, QMetaType::QColor, 0x00495103,
      34, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       8,
      10,
      11,
      12,
      13,
      14,

       0        // eod
};

void QtCharts::QXYSeries::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QXYSeries *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clicked((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 1: _t->hovered((*reinterpret_cast< const QPointF(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->pressed((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 3: _t->released((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 4: _t->doubleClicked((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 5: _t->pointReplaced((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->pointRemoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->pointAdded((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->colorChanged((*reinterpret_cast< QColor(*)>(_a[1]))); break;
        case 9: _t->pointsReplaced(); break;
        case 10: _t->pointLabelsFormatChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->pointLabelsVisibilityChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->pointLabelsFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 13: _t->pointLabelsColorChanged((*reinterpret_cast< const QColor(*)>(_a[1]))); break;
        case 14: _t->pointLabelsClippingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->pointsRemoved((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 16: _t->penChanged((*reinterpret_cast< const QPen(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QXYSeries::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::clicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QPointF & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::hovered)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pressed)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::released)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::doubleClicked)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointReplaced)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointRemoved)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointAdded)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(QColor );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::colorChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointsReplaced)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointLabelsFormatChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointLabelsVisibilityChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QFont & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointLabelsFontChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QColor & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointLabelsColorChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointLabelsClippingChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::pointsRemoved)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (QXYSeries::*)(const QPen & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QXYSeries::penChanged)) {
                *result = 16;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QXYSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->pointsVisible(); break;
        case 1: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->pointLabelsFormat(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->pointLabelsVisible(); break;
        case 4: *reinterpret_cast< QFont*>(_v) = _t->pointLabelsFont(); break;
        case 5: *reinterpret_cast< QColor*>(_v) = _t->pointLabelsColor(); break;
        case 6: *reinterpret_cast< bool*>(_v) = _t->pointLabelsClipping(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QXYSeries *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPointsVisible(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 2: _t->setPointLabelsFormat(*reinterpret_cast< QString*>(_v)); break;
        case 3: _t->setPointLabelsVisible(*reinterpret_cast< bool*>(_v)); break;
        case 4: _t->setPointLabelsFont(*reinterpret_cast< QFont*>(_v)); break;
        case 5: _t->setPointLabelsColor(*reinterpret_cast< QColor*>(_v)); break;
        case 6: _t->setPointLabelsClipping(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QtCharts::QXYSeries::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractSeries::staticMetaObject>(),
    qt_meta_stringdata_QtCharts__QXYSeries.data,
    qt_meta_data_QtCharts__QXYSeries,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QtCharts::QXYSeries::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QtCharts::QXYSeries::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QtCharts__QXYSeries.stringdata0))
        return static_cast<void*>(this);
    return QAbstractSeries::qt_metacast(_clname);
}

int QtCharts::QXYSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractSeries::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 7;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 7;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QtCharts::QXYSeries::clicked(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void QtCharts::QXYSeries::hovered(const QPointF & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QtCharts::QXYSeries::pressed(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QtCharts::QXYSeries::released(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QtCharts::QXYSeries::doubleClicked(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void QtCharts::QXYSeries::pointReplaced(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void QtCharts::QXYSeries::pointRemoved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void QtCharts::QXYSeries::pointAdded(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void QtCharts::QXYSeries::colorChanged(QColor _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void QtCharts::QXYSeries::pointsReplaced()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QtCharts::QXYSeries::pointLabelsFormatChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void QtCharts::QXYSeries::pointLabelsVisibilityChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void QtCharts::QXYSeries::pointLabelsFontChanged(const QFont & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void QtCharts::QXYSeries::pointLabelsColorChanged(const QColor & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void QtCharts::QXYSeries::pointLabelsClippingChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void QtCharts::QXYSeries::pointsRemoved(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void QtCharts::QXYSeries::penChanged(const QPen & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
